"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputaudio import InputAudio, InputAudioTypedDict
from .inputfile import InputFile, InputFileTypedDict
from .inputtext import InputText, InputTextTypedDict
from .inputvideo import InputVideo, InputVideoTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_open_enum
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


InputMessageItemTypeMessage = Literal["message",]


InputMessageItemRoleDeveloper = Literal["developer",]


InputMessageItemRoleSystem = Literal["system",]


InputMessageItemRoleUser = Literal["user",]


InputMessageItemRoleUnionTypedDict = TypeAliasType(
    "InputMessageItemRoleUnionTypedDict",
    Union[
        InputMessageItemRoleUser,
        InputMessageItemRoleSystem,
        InputMessageItemRoleDeveloper,
    ],
)


InputMessageItemRoleUnion = TypeAliasType(
    "InputMessageItemRoleUnion",
    Union[
        InputMessageItemRoleUser,
        InputMessageItemRoleSystem,
        InputMessageItemRoleDeveloper,
    ],
)


InputMessageItemContentType = Literal["input_image",]


InputMessageItemDetail = Union[
    Literal[
        "auto",
        "high",
        "low",
    ],
    UnrecognizedStr,
]


class InputMessageItemContentInputImageTypedDict(TypedDict):
    r"""Image input content item"""

    type: InputMessageItemContentType
    detail: InputMessageItemDetail
    image_url: NotRequired[Nullable[str]]


class InputMessageItemContentInputImage(BaseModel):
    r"""Image input content item"""

    type: InputMessageItemContentType

    detail: Annotated[InputMessageItemDetail, PlainValidator(validate_open_enum(False))]

    image_url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["image_url"]
        nullable_fields = ["image_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


InputMessageItemContentUnionTypedDict = TypeAliasType(
    "InputMessageItemContentUnionTypedDict",
    Union[
        InputTextTypedDict,
        InputAudioTypedDict,
        InputVideoTypedDict,
        InputMessageItemContentInputImageTypedDict,
        InputFileTypedDict,
    ],
)


InputMessageItemContentUnion = Annotated[
    Union[
        Annotated[InputText, Tag("input_text")],
        Annotated[InputMessageItemContentInputImage, Tag("input_image")],
        Annotated[InputFile, Tag("input_file")],
        Annotated[InputAudio, Tag("input_audio")],
        Annotated[InputVideo, Tag("input_video")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


class InputMessageItemTypedDict(TypedDict):
    role: InputMessageItemRoleUnionTypedDict
    id: NotRequired[str]
    type: NotRequired[InputMessageItemTypeMessage]
    content: NotRequired[Nullable[List[InputMessageItemContentUnionTypedDict]]]


class InputMessageItem(BaseModel):
    role: InputMessageItemRoleUnion

    id: Optional[str] = None

    type: Optional[InputMessageItemTypeMessage] = None

    content: OptionalNullable[List[InputMessageItemContentUnion]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "type", "content"]
        nullable_fields = ["content"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
