"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcontenttext import ChatContentText, ChatContentTextTypedDict
from openrouter.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


ChatDeveloperMessageRole = Literal["developer",]


ChatDeveloperMessageContentTypedDict = TypeAliasType(
    "ChatDeveloperMessageContentTypedDict", Union[str, List[ChatContentTextTypedDict]]
)
r"""Developer message content"""


ChatDeveloperMessageContent = TypeAliasType(
    "ChatDeveloperMessageContent", Union[str, List[ChatContentText]]
)
r"""Developer message content"""


class ChatDeveloperMessageTypedDict(TypedDict):
    r"""Developer message"""

    role: ChatDeveloperMessageRole
    content: ChatDeveloperMessageContentTypedDict
    r"""Developer message content"""
    name: NotRequired[str]
    r"""Optional name for the developer message"""


class ChatDeveloperMessage(BaseModel):
    r"""Developer message"""

    role: ChatDeveloperMessageRole

    content: ChatDeveloperMessageContent
    r"""Developer message content"""

    name: Optional[str] = None
    r"""Optional name for the developer message"""
