"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatFormatTextConfigType = Literal["text",]


class ChatFormatTextConfigTypedDict(TypedDict):
    r"""Default text response format"""

    type: ChatFormatTextConfigType


class ChatFormatTextConfig(BaseModel):
    r"""Default text response format"""

    type: ChatFormatTextConfigType
