"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemtext import (
    ChatMessageContentItemText,
    ChatMessageContentItemTextTypedDict,
)
from openrouter.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


DeveloperMessageRole = Literal["developer",]


DeveloperMessageContentTypedDict = TypeAliasType(
    "DeveloperMessageContentTypedDict",
    Union[str, List[ChatMessageContentItemTextTypedDict]],
)
r"""Developer message content"""


DeveloperMessageContent = TypeAliasType(
    "DeveloperMessageContent", Union[str, List[ChatMessageContentItemText]]
)
r"""Developer message content"""


class DeveloperMessageTypedDict(TypedDict):
    r"""Developer message"""

    role: DeveloperMessageRole
    content: DeveloperMessageContentTypedDict
    r"""Developer message content"""
    name: NotRequired[str]
    r"""Optional name for the developer message"""


class DeveloperMessage(BaseModel):
    r"""Developer message"""

    role: DeveloperMessageRole

    content: DeveloperMessageContent
    r"""Developer message content"""

    name: Optional[str] = None
    r"""Optional name for the developer message"""
