"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


WebSearchCallSearchingEventType = Literal["response.web_search_call.searching",]


class WebSearchCallSearchingEventTypedDict(TypedDict):
    r"""Web search call is searching"""

    type: WebSearchCallSearchingEventType
    item_id: str
    output_index: float
    sequence_number: float


class WebSearchCallSearchingEvent(BaseModel):
    r"""Web search call is searching"""

    type: WebSearchCallSearchingEventType

    item_id: str

    output_index: float

    sequence_number: float
