"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ReasoningSummaryTextDoneEventType = Literal["response.reasoning_summary_text.done",]


class ReasoningSummaryTextDoneEventTypedDict(TypedDict):
    r"""Event emitted when reasoning summary text streaming is complete"""

    type: ReasoningSummaryTextDoneEventType
    item_id: str
    output_index: float
    summary_index: float
    text: str
    sequence_number: float


class ReasoningSummaryTextDoneEvent(BaseModel):
    r"""Event emitted when reasoning summary text streaming is complete"""

    type: ReasoningSummaryTextDoneEventType

    item_id: str

    output_index: float

    summary_index: float

    text: str

    sequence_number: float
