"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitem import (
    ChatMessageContentItem,
    ChatMessageContentItemTypedDict,
)
from openrouter.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


UserMessageRole = Literal["user",]


UserMessageContentTypedDict = TypeAliasType(
    "UserMessageContentTypedDict", Union[str, List[ChatMessageContentItemTypedDict]]
)
r"""User message content"""


UserMessageContent = TypeAliasType(
    "UserMessageContent", Union[str, List[ChatMessageContentItem]]
)
r"""User message content"""


class UserMessageTypedDict(TypedDict):
    r"""User message"""

    role: UserMessageRole
    content: UserMessageContentTypedDict
    r"""User message content"""
    name: NotRequired[str]
    r"""Optional name for the user"""


class UserMessage(BaseModel):
    r"""User message"""

    role: UserMessageRole

    content: UserMessageContent
    r"""User message content"""

    name: Optional[str] = None
    r"""Optional name for the user"""
