"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pdfparserengine import PDFParserEngine, PDFParserEngineTypedDict
from openrouter.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PDFParserOptionsTypedDict(TypedDict):
    r"""Options for PDF parsing."""

    engine: NotRequired[PDFParserEngineTypedDict]
    r"""The engine to use for parsing PDF files. \"pdf-text\" is deprecated and automatically redirected to \"cloudflare-ai\"."""


class PDFParserOptions(BaseModel):
    r"""Options for PDF parsing."""

    engine: Optional[PDFParserEngine] = None
    r"""The engine to use for parsing PDF files. \"pdf-text\" is deprecated and automatically redirected to \"cloudflare-ai\"."""
