"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputaudio import InputAudio, InputAudioTypedDict
from .inputfile import InputFile, InputFileTypedDict
from .inputtext import InputText, InputTextTypedDict
from .inputvideo import InputVideo, InputVideoTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_open_enum
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Any, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


EasyInputMessageTypeMessage = Literal["message",]


EasyInputMessageRoleDeveloper = Literal["developer",]


EasyInputMessageRoleAssistant = Literal["assistant",]


EasyInputMessageRoleSystem = Literal["system",]


EasyInputMessageRoleUser = Literal["user",]


EasyInputMessageRoleUnionTypedDict = TypeAliasType(
    "EasyInputMessageRoleUnionTypedDict",
    Union[
        EasyInputMessageRoleUser,
        EasyInputMessageRoleSystem,
        EasyInputMessageRoleAssistant,
        EasyInputMessageRoleDeveloper,
    ],
)


EasyInputMessageRoleUnion = TypeAliasType(
    "EasyInputMessageRoleUnion",
    Union[
        EasyInputMessageRoleUser,
        EasyInputMessageRoleSystem,
        EasyInputMessageRoleAssistant,
        EasyInputMessageRoleDeveloper,
    ],
)


EasyInputMessageContentType = Literal["input_image",]


EasyInputMessageDetail = Union[
    Literal[
        "auto",
        "high",
        "low",
    ],
    UnrecognizedStr,
]


class EasyInputMessageContentInputImageTypedDict(TypedDict):
    r"""Image input content item"""

    type: EasyInputMessageContentType
    detail: EasyInputMessageDetail
    image_url: NotRequired[Nullable[str]]


class EasyInputMessageContentInputImage(BaseModel):
    r"""Image input content item"""

    type: EasyInputMessageContentType

    detail: Annotated[EasyInputMessageDetail, PlainValidator(validate_open_enum(False))]

    image_url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["image_url"]
        nullable_fields = ["image_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


EasyInputMessageContentUnion1TypedDict = TypeAliasType(
    "EasyInputMessageContentUnion1TypedDict",
    Union[
        InputTextTypedDict,
        InputAudioTypedDict,
        InputVideoTypedDict,
        EasyInputMessageContentInputImageTypedDict,
        InputFileTypedDict,
    ],
)


EasyInputMessageContentUnion1 = Annotated[
    Union[
        Annotated[InputText, Tag("input_text")],
        Annotated[EasyInputMessageContentInputImage, Tag("input_image")],
        Annotated[InputFile, Tag("input_file")],
        Annotated[InputAudio, Tag("input_audio")],
        Annotated[InputVideo, Tag("input_video")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


EasyInputMessageContentUnion2TypedDict = TypeAliasType(
    "EasyInputMessageContentUnion2TypedDict",
    Union[List[EasyInputMessageContentUnion1TypedDict], str, Any],
)


EasyInputMessageContentUnion2 = TypeAliasType(
    "EasyInputMessageContentUnion2",
    Union[List[EasyInputMessageContentUnion1], str, Any],
)


EasyInputMessagePhaseFinalAnswer = Literal["final_answer",]


EasyInputMessagePhaseCommentary = Literal["commentary",]


EasyInputMessagePhaseUnionTypedDict = TypeAliasType(
    "EasyInputMessagePhaseUnionTypedDict",
    Union[EasyInputMessagePhaseCommentary, EasyInputMessagePhaseFinalAnswer, Any],
)
r"""The phase of an assistant message. Use `commentary` for an intermediate assistant message and `final_answer` for the final assistant message. For follow-up requests with models like `gpt-5.3-codex` and later, preserve and resend phase on all assistant messages. Omitting it can degrade performance. Not used for user messages."""


EasyInputMessagePhaseUnion = TypeAliasType(
    "EasyInputMessagePhaseUnion",
    Union[EasyInputMessagePhaseCommentary, EasyInputMessagePhaseFinalAnswer, Any],
)
r"""The phase of an assistant message. Use `commentary` for an intermediate assistant message and `final_answer` for the final assistant message. For follow-up requests with models like `gpt-5.3-codex` and later, preserve and resend phase on all assistant messages. Omitting it can degrade performance. Not used for user messages."""


class EasyInputMessageTypedDict(TypedDict):
    role: EasyInputMessageRoleUnionTypedDict
    type: NotRequired[EasyInputMessageTypeMessage]
    content: NotRequired[Nullable[EasyInputMessageContentUnion2TypedDict]]
    phase: NotRequired[Nullable[EasyInputMessagePhaseUnionTypedDict]]
    r"""The phase of an assistant message. Use `commentary` for an intermediate assistant message and `final_answer` for the final assistant message. For follow-up requests with models like `gpt-5.3-codex` and later, preserve and resend phase on all assistant messages. Omitting it can degrade performance. Not used for user messages."""


class EasyInputMessage(BaseModel):
    role: EasyInputMessageRoleUnion

    type: Optional[EasyInputMessageTypeMessage] = None

    content: OptionalNullable[EasyInputMessageContentUnion2] = UNSET

    phase: OptionalNullable[EasyInputMessagePhaseUnion] = UNSET
    r"""The phase of an assistant message. Use `commentary` for an intermediate assistant message and `final_answer` for the final assistant message. For follow-up requests with models like `gpt-5.3-codex` and later, preserve and resend phase on all assistant messages. Omitting it can degrade performance. Not used for user messages."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["type", "content", "phase"]
        nullable_fields = ["content", "phase"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
