"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chataudiooutput import ChatAudioOutput, ChatAudioOutputTypedDict
from .chatstreamtoolcall import ChatStreamToolCall, ChatStreamToolCallTypedDict
from .reasoningdetailunion import ReasoningDetailUnion, ReasoningDetailUnionTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


ChatStreamDeltaRole = Literal["assistant",]
r"""The role of the message author"""


class ChatStreamDeltaTypedDict(TypedDict):
    r"""Delta changes in streaming response"""

    role: NotRequired[ChatStreamDeltaRole]
    r"""The role of the message author"""
    content: NotRequired[Nullable[str]]
    r"""Message content delta"""
    reasoning: NotRequired[Nullable[str]]
    r"""Reasoning content delta"""
    refusal: NotRequired[Nullable[str]]
    r"""Refusal message delta"""
    tool_calls: NotRequired[List[ChatStreamToolCallTypedDict]]
    r"""Tool calls delta"""
    reasoning_details: NotRequired[List[ReasoningDetailUnionTypedDict]]
    r"""Reasoning details for extended thinking models"""
    audio: NotRequired[ChatAudioOutputTypedDict]


class ChatStreamDelta(BaseModel):
    r"""Delta changes in streaming response"""

    role: Optional[ChatStreamDeltaRole] = None
    r"""The role of the message author"""

    content: OptionalNullable[str] = UNSET
    r"""Message content delta"""

    reasoning: OptionalNullable[str] = UNSET
    r"""Reasoning content delta"""

    refusal: OptionalNullable[str] = UNSET
    r"""Refusal message delta"""

    tool_calls: Optional[List[ChatStreamToolCall]] = None
    r"""Tool calls delta"""

    reasoning_details: Optional[List[ReasoningDetailUnion]] = None
    r"""Reasoning details for extended thinking models"""

    audio: Optional[ChatAudioOutput] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "role",
            "content",
            "reasoning",
            "refusal",
            "tool_calls",
            "reasoning_details",
            "audio",
        ]
        nullable_fields = ["content", "reasoning", "refusal"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
