"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcontentvideoinput import ChatContentVideoInput, ChatContentVideoInputTypedDict
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict, deprecated


LegacyChatContentVideoType = Literal["input_video",]


@deprecated(
    "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
)
class LegacyChatContentVideoTypedDict(TypedDict):
    r"""Video input content part (legacy format - deprecated)"""

    type: LegacyChatContentVideoType
    video_url: ChatContentVideoInputTypedDict
    r"""Video input object"""


@deprecated(
    "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
)
class LegacyChatContentVideo(BaseModel):
    r"""Video input content part (legacy format - deprecated)"""

    type: LegacyChatContentVideoType

    video_url: ChatContentVideoInput
    r"""Video input object"""
