"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .namedtoolchoice import NamedToolChoice, NamedToolChoiceTypedDict
from typing import Literal, Union
from typing_extensions import TypeAliasType


ToolChoiceOptionRequired = Literal["required",]


ToolChoiceOptionAuto = Literal["auto",]


ToolChoiceOptionNone = Literal["none",]


ToolChoiceOptionTypedDict = TypeAliasType(
    "ToolChoiceOptionTypedDict",
    Union[
        NamedToolChoiceTypedDict,
        ToolChoiceOptionNone,
        ToolChoiceOptionAuto,
        ToolChoiceOptionRequired,
    ],
)
r"""Tool choice configuration"""


ToolChoiceOption = TypeAliasType(
    "ToolChoiceOption",
    Union[
        NamedToolChoice,
        ToolChoiceOptionNone,
        ToolChoiceOptionAuto,
        ToolChoiceOptionRequired,
    ],
)
r"""Tool choice configuration"""
