"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openairesponsesannotation import (
    OpenAIResponsesAnnotation,
    OpenAIResponsesAnnotationTypedDict,
)
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


AnnotationAddedEventType = Literal["response.output_text.annotation.added",]


class AnnotationAddedEventTypedDict(TypedDict):
    r"""Event emitted when a text annotation is added to output"""

    type: AnnotationAddedEventType
    output_index: float
    item_id: str
    content_index: float
    sequence_number: float
    annotation_index: float
    annotation: OpenAIResponsesAnnotationTypedDict


class AnnotationAddedEvent(BaseModel):
    r"""Event emitted when a text annotation is added to output"""

    type: AnnotationAddedEventType

    output_index: float

    item_id: str

    content_index: float

    sequence_number: float

    annotation_index: float

    annotation: OpenAIResponsesAnnotation
