"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemcachecontrol import (
    ChatMessageContentItemCacheControl,
    ChatMessageContentItemCacheControlTypedDict,
)
from openrouter.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


ChatMessageContentItemTextType = Literal["text",]


class ChatMessageContentItemTextTypedDict(TypedDict):
    r"""Text content part"""

    type: ChatMessageContentItemTextType
    text: str
    cache_control: NotRequired[ChatMessageContentItemCacheControlTypedDict]
    r"""Cache control for the content part"""


class ChatMessageContentItemText(BaseModel):
    r"""Text content part"""

    type: ChatMessageContentItemTextType

    text: str

    cache_control: Optional[ChatMessageContentItemCacheControl] = None
    r"""Cache control for the content part"""
