"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatMessageToolCallType = Literal["function",]


class ChatMessageToolCallFunctionTypedDict(TypedDict):
    name: str
    r"""Function name to call"""
    arguments: str
    r"""Function arguments as JSON string"""


class ChatMessageToolCallFunction(BaseModel):
    name: str
    r"""Function name to call"""

    arguments: str
    r"""Function arguments as JSON string"""


class ChatMessageToolCallTypedDict(TypedDict):
    r"""Tool call made by the assistant"""

    id: str
    r"""Tool call identifier"""
    type: ChatMessageToolCallType
    function: ChatMessageToolCallFunctionTypedDict


class ChatMessageToolCall(BaseModel):
    r"""Tool call made by the assistant"""

    id: str
    r"""Tool call identifier"""

    type: ChatMessageToolCallType

    function: ChatMessageToolCallFunction
