"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


NamedToolChoiceType = Literal["function",]


class NamedToolChoiceFunctionTypedDict(TypedDict):
    name: str
    r"""Function name to call"""


class NamedToolChoiceFunction(BaseModel):
    name: str
    r"""Function name to call"""


class NamedToolChoiceTypedDict(TypedDict):
    r"""Named tool choice for specific function"""

    type: NamedToolChoiceType
    function: NamedToolChoiceFunctionTypedDict


class NamedToolChoice(BaseModel):
    r"""Named tool choice for specific function"""

    type: NamedToolChoiceType

    function: NamedToolChoiceFunction
