"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


FunctionCallArgsDoneEventType = Literal["response.function_call_arguments.done",]


class FunctionCallArgsDoneEventTypedDict(TypedDict):
    r"""Event emitted when function call arguments streaming is complete"""

    type: FunctionCallArgsDoneEventType
    item_id: str
    output_index: float
    name: str
    arguments: str
    sequence_number: float


class FunctionCallArgsDoneEvent(BaseModel):
    r"""Event emitted when function call arguments streaming is complete"""

    type: FunctionCallArgsDoneEventType

    item_id: str

    output_index: float

    name: str

    arguments: str

    sequence_number: float
