"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatnamedtoolchoice import ChatNamedToolChoice, ChatNamedToolChoiceTypedDict
from typing import Literal, Union
from typing_extensions import TypeAliasType


ChatToolChoiceRequired = Literal["required",]


ChatToolChoiceAuto = Literal["auto",]


ChatToolChoiceNone = Literal["none",]


ChatToolChoiceTypedDict = TypeAliasType(
    "ChatToolChoiceTypedDict",
    Union[
        ChatNamedToolChoiceTypedDict,
        ChatToolChoiceNone,
        ChatToolChoiceAuto,
        ChatToolChoiceRequired,
    ],
)
r"""Tool choice configuration"""


ChatToolChoice = TypeAliasType(
    "ChatToolChoice",
    Union[
        ChatNamedToolChoice,
        ChatToolChoiceNone,
        ChatToolChoiceAuto,
        ChatToolChoiceRequired,
    ],
)
r"""Tool choice configuration"""
