"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseFormatJSONObjectType = Literal["json_object",]


class ResponseFormatJSONObjectTypedDict(TypedDict):
    r"""JSON object response format"""

    type: ResponseFormatJSONObjectType


class ResponseFormatJSONObject(BaseModel):
    r"""JSON object response format"""

    type: ResponseFormatJSONObjectType
