"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class VideoInputTypedDict(TypedDict):
    r"""Video input object"""

    url: str
    r"""URL of the video (data: URLs supported)"""


class VideoInput(BaseModel):
    r"""Video input object"""

    url: str
    r"""URL of the video (data: URLs supported)"""
