"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .outputfilesearchcallitem import (
    OutputFileSearchCallItem,
    OutputFileSearchCallItemTypedDict,
)
from .outputfunctioncallitem import (
    OutputFunctionCallItem,
    OutputFunctionCallItemTypedDict,
)
from .outputimagegenerationcallitem import (
    OutputImageGenerationCallItem,
    OutputImageGenerationCallItemTypedDict,
)
from .outputmessageitem import OutputMessageItem, OutputMessageItemTypedDict
from .outputreasoningitem import OutputReasoningItem, OutputReasoningItemTypedDict
from .outputservertoolitem import OutputServerToolItem, OutputServerToolItemTypedDict
from .outputwebsearchcallitem import (
    OutputWebSearchCallItem,
    OutputWebSearchCallItemTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


OutputItemsTypedDict = TypeAliasType(
    "OutputItemsTypedDict",
    Union[
        OutputWebSearchCallItemTypedDict,
        OutputFileSearchCallItemTypedDict,
        OutputImageGenerationCallItemTypedDict,
        OutputServerToolItemTypedDict,
        OutputMessageItemTypedDict,
        OutputFunctionCallItemTypedDict,
        OutputReasoningItemTypedDict,
    ],
)
r"""An output item from the response"""


OutputItems = TypeAliasType(
    "OutputItems",
    Union[
        OutputWebSearchCallItem,
        OutputFileSearchCallItem,
        OutputImageGenerationCallItem,
        OutputServerToolItem,
        OutputMessageItem,
        OutputFunctionCallItem,
        OutputReasoningItem,
    ],
)
r"""An output item from the response"""
