"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcontentvideoinput import ChatContentVideoInput, ChatContentVideoInputTypedDict
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatContentVideoType = Literal["video_url",]


class ChatContentVideoTypedDict(TypedDict):
    r"""Video input content part"""

    type: ChatContentVideoType
    video_url: ChatContentVideoInputTypedDict
    r"""Video input object"""


class ChatContentVideo(BaseModel):
    r"""Video input content part"""

    type: ChatContentVideoType

    video_url: ChatContentVideoInput
    r"""Video input object"""
