"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatNamedToolChoiceType = Literal["function",]


class ChatNamedToolChoiceFunctionTypedDict(TypedDict):
    name: str
    r"""Function name to call"""


class ChatNamedToolChoiceFunction(BaseModel):
    name: str
    r"""Function name to call"""


class ChatNamedToolChoiceTypedDict(TypedDict):
    r"""Named tool choice for specific function"""

    type: ChatNamedToolChoiceType
    function: ChatNamedToolChoiceFunctionTypedDict


class ChatNamedToolChoice(BaseModel):
    r"""Named tool choice for specific function"""

    type: ChatNamedToolChoiceType

    function: ChatNamedToolChoiceFunction
