"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesFunctionShellToolType = Literal["shell",]


class OpenResponsesFunctionShellToolTypedDict(TypedDict):
    r"""Shell tool configuration"""

    type: OpenResponsesFunctionShellToolType


class OpenResponsesFunctionShellTool(BaseModel):
    r"""Shell tool configuration"""

    type: OpenResponsesFunctionShellToolType
