"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jsonschemaconfig import JSONSchemaConfig, JSONSchemaConfigTypedDict
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseFormatJSONSchemaType = Literal["json_schema",]


class ResponseFormatJSONSchemaTypedDict(TypedDict):
    r"""JSON Schema response format for structured outputs"""

    type: ResponseFormatJSONSchemaType
    json_schema: JSONSchemaConfigTypedDict
    r"""JSON Schema configuration object"""


class ResponseFormatJSONSchema(BaseModel):
    r"""JSON Schema response format for structured outputs"""

    type: ResponseFormatJSONSchemaType

    json_schema: JSONSchemaConfig
    r"""JSON Schema configuration object"""
