"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


FunctionCallArgsDeltaEventType = Literal["response.function_call_arguments.delta",]


class FunctionCallArgsDeltaEventTypedDict(TypedDict):
    r"""Event emitted when function call arguments are being streamed"""

    type: FunctionCallArgsDeltaEventType
    item_id: str
    output_index: float
    delta: str
    sequence_number: float


class FunctionCallArgsDeltaEvent(BaseModel):
    r"""Event emitted when function call arguments are being streamed"""

    type: FunctionCallArgsDeltaEventType

    item_id: str

    output_index: float

    delta: str

    sequence_number: float
