"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .bulkassignkeystoguardrail import (
        BulkAssignKeysToGuardrailGlobals,
        BulkAssignKeysToGuardrailGlobalsTypedDict,
        BulkAssignKeysToGuardrailRequest,
        BulkAssignKeysToGuardrailRequestBody,
        BulkAssignKeysToGuardrailRequestBodyTypedDict,
        BulkAssignKeysToGuardrailRequestTypedDict,
        BulkAssignKeysToGuardrailResponse,
        BulkAssignKeysToGuardrailResponseTypedDict,
    )
    from .bulkassignmemberstoguardrail import (
        BulkAssignMembersToGuardrailGlobals,
        BulkAssignMembersToGuardrailGlobalsTypedDict,
        BulkAssignMembersToGuardrailRequest,
        BulkAssignMembersToGuardrailRequestBody,
        BulkAssignMembersToGuardrailRequestBodyTypedDict,
        BulkAssignMembersToGuardrailRequestTypedDict,
        BulkAssignMembersToGuardrailResponse,
        BulkAssignMembersToGuardrailResponseTypedDict,
    )
    from .bulkunassignkeysfromguardrail import (
        BulkUnassignKeysFromGuardrailGlobals,
        BulkUnassignKeysFromGuardrailGlobalsTypedDict,
        BulkUnassignKeysFromGuardrailRequest,
        BulkUnassignKeysFromGuardrailRequestBody,
        BulkUnassignKeysFromGuardrailRequestBodyTypedDict,
        BulkUnassignKeysFromGuardrailRequestTypedDict,
        BulkUnassignKeysFromGuardrailResponse,
        BulkUnassignKeysFromGuardrailResponseTypedDict,
    )
    from .bulkunassignmembersfromguardrail import (
        BulkUnassignMembersFromGuardrailGlobals,
        BulkUnassignMembersFromGuardrailGlobalsTypedDict,
        BulkUnassignMembersFromGuardrailRequest,
        BulkUnassignMembersFromGuardrailRequestBody,
        BulkUnassignMembersFromGuardrailRequestBodyTypedDict,
        BulkUnassignMembersFromGuardrailRequestTypedDict,
        BulkUnassignMembersFromGuardrailResponse,
        BulkUnassignMembersFromGuardrailResponseTypedDict,
    )
    from .createauthkeyscode import (
        CreateAuthKeysCodeCodeChallengeMethod,
        CreateAuthKeysCodeData,
        CreateAuthKeysCodeDataTypedDict,
        CreateAuthKeysCodeGlobals,
        CreateAuthKeysCodeGlobalsTypedDict,
        CreateAuthKeysCodeRequest,
        CreateAuthKeysCodeRequestBody,
        CreateAuthKeysCodeRequestBodyTypedDict,
        CreateAuthKeysCodeRequestTypedDict,
        CreateAuthKeysCodeResponse,
        CreateAuthKeysCodeResponseTypedDict,
        UsageLimitType,
    )
    from .createcoinbasecharge import (
        CallData,
        CallDataTypedDict,
        CreateCoinbaseChargeData,
        CreateCoinbaseChargeDataTypedDict,
        CreateCoinbaseChargeGlobals,
        CreateCoinbaseChargeGlobalsTypedDict,
        CreateCoinbaseChargeRequest,
        CreateCoinbaseChargeRequestTypedDict,
        CreateCoinbaseChargeResponse,
        CreateCoinbaseChargeResponseTypedDict,
        CreateCoinbaseChargeSecurity,
        CreateCoinbaseChargeSecurityTypedDict,
        Metadata,
        MetadataTypedDict,
        TransferIntent,
        TransferIntentTypedDict,
        Web3Data,
        Web3DataTypedDict,
    )
    from .createembeddings import (
        Content,
        ContentImageURL,
        ContentImageURLTypedDict,
        ContentText,
        ContentTextTypedDict,
        ContentTypedDict,
        CreateEmbeddingsData,
        CreateEmbeddingsDataTypedDict,
        CreateEmbeddingsGlobals,
        CreateEmbeddingsGlobalsTypedDict,
        CreateEmbeddingsRequest,
        CreateEmbeddingsRequestBody,
        CreateEmbeddingsRequestBodyTypedDict,
        CreateEmbeddingsRequestTypedDict,
        CreateEmbeddingsResponse,
        CreateEmbeddingsResponseBody,
        CreateEmbeddingsResponseBodyTypedDict,
        CreateEmbeddingsResponseTypedDict,
        Embedding,
        EmbeddingTypedDict,
        EncodingFormat,
        ImageURL,
        ImageURLTypedDict,
        Input,
        InputTypedDict,
        InputUnion,
        InputUnionTypedDict,
        Object,
        ObjectEmbedding,
        TypeImageURL,
        TypeText,
        Usage,
        UsageTypedDict,
    )
    from .createguardrail import (
        CreateGuardrailData,
        CreateGuardrailDataTypedDict,
        CreateGuardrailGlobals,
        CreateGuardrailGlobalsTypedDict,
        CreateGuardrailRequest,
        CreateGuardrailRequestBody,
        CreateGuardrailRequestBodyTypedDict,
        CreateGuardrailRequestTypedDict,
        CreateGuardrailResetIntervalRequest,
        CreateGuardrailResetIntervalResponse,
        CreateGuardrailResponse,
        CreateGuardrailResponseTypedDict,
    )
    from .createkeys import (
        CreateKeysData,
        CreateKeysDataTypedDict,
        CreateKeysGlobals,
        CreateKeysGlobalsTypedDict,
        CreateKeysLimitReset,
        CreateKeysRequest,
        CreateKeysRequestBody,
        CreateKeysRequestBodyTypedDict,
        CreateKeysRequestTypedDict,
        CreateKeysResponse,
        CreateKeysResponseTypedDict,
    )
    from .createresponses import (
        CreateResponsesGlobals,
        CreateResponsesGlobalsTypedDict,
        CreateResponsesRequest,
        CreateResponsesRequestTypedDict,
        CreateResponsesResponse,
        CreateResponsesResponseBody,
        CreateResponsesResponseBodyTypedDict,
        CreateResponsesResponseTypedDict,
    )
    from .deleteguardrail import (
        DeleteGuardrailGlobals,
        DeleteGuardrailGlobalsTypedDict,
        DeleteGuardrailRequest,
        DeleteGuardrailRequestTypedDict,
        DeleteGuardrailResponse,
        DeleteGuardrailResponseTypedDict,
    )
    from .deletekeys import (
        DeleteKeysGlobals,
        DeleteKeysGlobalsTypedDict,
        DeleteKeysRequest,
        DeleteKeysRequestTypedDict,
        DeleteKeysResponse,
        DeleteKeysResponseTypedDict,
    )
    from .exchangeauthcodeforapikey import (
        ExchangeAuthCodeForAPIKeyCodeChallengeMethod,
        ExchangeAuthCodeForAPIKeyGlobals,
        ExchangeAuthCodeForAPIKeyGlobalsTypedDict,
        ExchangeAuthCodeForAPIKeyRequest,
        ExchangeAuthCodeForAPIKeyRequestBody,
        ExchangeAuthCodeForAPIKeyRequestBodyTypedDict,
        ExchangeAuthCodeForAPIKeyRequestTypedDict,
        ExchangeAuthCodeForAPIKeyResponse,
        ExchangeAuthCodeForAPIKeyResponseTypedDict,
    )
    from .getcredits import (
        GetCreditsData,
        GetCreditsDataTypedDict,
        GetCreditsGlobals,
        GetCreditsGlobalsTypedDict,
        GetCreditsRequest,
        GetCreditsRequestTypedDict,
        GetCreditsResponse,
        GetCreditsResponseTypedDict,
    )
    from .getcurrentkey import (
        GetCurrentKeyData,
        GetCurrentKeyDataTypedDict,
        GetCurrentKeyGlobals,
        GetCurrentKeyGlobalsTypedDict,
        GetCurrentKeyRequest,
        GetCurrentKeyRequestTypedDict,
        GetCurrentKeyResponse,
        GetCurrentKeyResponseTypedDict,
        RateLimit,
        RateLimitTypedDict,
    )
    from .getgeneration import (
        APIType,
        GetGenerationData,
        GetGenerationDataTypedDict,
        GetGenerationGlobals,
        GetGenerationGlobalsTypedDict,
        GetGenerationRequest,
        GetGenerationRequestTypedDict,
        GetGenerationResponse,
        GetGenerationResponseTypedDict,
        ProviderName,
        ProviderResponse,
        ProviderResponseTypedDict,
    )
    from .getguardrail import (
        GetGuardrailData,
        GetGuardrailDataTypedDict,
        GetGuardrailGlobals,
        GetGuardrailGlobalsTypedDict,
        GetGuardrailRequest,
        GetGuardrailRequestTypedDict,
        GetGuardrailResetInterval,
        GetGuardrailResponse,
        GetGuardrailResponseTypedDict,
    )
    from .getkey import (
        GetKeyData,
        GetKeyDataTypedDict,
        GetKeyGlobals,
        GetKeyGlobalsTypedDict,
        GetKeyRequest,
        GetKeyRequestTypedDict,
        GetKeyResponse,
        GetKeyResponseTypedDict,
    )
    from .getmodels import (
        Category,
        GetModelsGlobals,
        GetModelsGlobalsTypedDict,
        GetModelsRequest,
        GetModelsRequestTypedDict,
    )
    from .getuseractivity import (
        GetUserActivityGlobals,
        GetUserActivityGlobalsTypedDict,
        GetUserActivityRequest,
        GetUserActivityRequestTypedDict,
        GetUserActivityResponse,
        GetUserActivityResponseTypedDict,
    )
    from .list import (
        ListData,
        ListDataTypedDict,
        ListGlobals,
        ListGlobalsTypedDict,
        ListRequest,
        ListRequestTypedDict,
        ListResponse,
        ListResponseTypedDict,
    )
    from .listembeddingsmodels import (
        ListEmbeddingsModelsGlobals,
        ListEmbeddingsModelsGlobalsTypedDict,
        ListEmbeddingsModelsRequest,
        ListEmbeddingsModelsRequestTypedDict,
    )
    from .listendpoints import (
        ListEndpointsGlobals,
        ListEndpointsGlobalsTypedDict,
        ListEndpointsRequest,
        ListEndpointsRequestTypedDict,
        ListEndpointsResponse,
        ListEndpointsResponseTypedDict,
    )
    from .listendpointszdr import (
        ListEndpointsZdrGlobals,
        ListEndpointsZdrGlobalsTypedDict,
        ListEndpointsZdrRequest,
        ListEndpointsZdrRequestTypedDict,
        ListEndpointsZdrResponse,
        ListEndpointsZdrResponseTypedDict,
    )
    from .listguardrailkeyassignments import (
        ListGuardrailKeyAssignmentsData,
        ListGuardrailKeyAssignmentsDataTypedDict,
        ListGuardrailKeyAssignmentsGlobals,
        ListGuardrailKeyAssignmentsGlobalsTypedDict,
        ListGuardrailKeyAssignmentsRequest,
        ListGuardrailKeyAssignmentsRequestTypedDict,
        ListGuardrailKeyAssignmentsResponse,
        ListGuardrailKeyAssignmentsResponseTypedDict,
    )
    from .listguardrailmemberassignments import (
        ListGuardrailMemberAssignmentsData,
        ListGuardrailMemberAssignmentsDataTypedDict,
        ListGuardrailMemberAssignmentsGlobals,
        ListGuardrailMemberAssignmentsGlobalsTypedDict,
        ListGuardrailMemberAssignmentsRequest,
        ListGuardrailMemberAssignmentsRequestTypedDict,
        ListGuardrailMemberAssignmentsResponse,
        ListGuardrailMemberAssignmentsResponseTypedDict,
    )
    from .listguardrails import (
        ListGuardrailsData,
        ListGuardrailsDataTypedDict,
        ListGuardrailsGlobals,
        ListGuardrailsGlobalsTypedDict,
        ListGuardrailsRequest,
        ListGuardrailsRequestTypedDict,
        ListGuardrailsResetInterval,
        ListGuardrailsResponse,
        ListGuardrailsResponseTypedDict,
    )
    from .listkeyassignments import (
        ListKeyAssignmentsData,
        ListKeyAssignmentsDataTypedDict,
        ListKeyAssignmentsGlobals,
        ListKeyAssignmentsGlobalsTypedDict,
        ListKeyAssignmentsRequest,
        ListKeyAssignmentsRequestTypedDict,
        ListKeyAssignmentsResponse,
        ListKeyAssignmentsResponseTypedDict,
    )
    from .listmemberassignments import (
        ListMemberAssignmentsData,
        ListMemberAssignmentsDataTypedDict,
        ListMemberAssignmentsGlobals,
        ListMemberAssignmentsGlobalsTypedDict,
        ListMemberAssignmentsRequest,
        ListMemberAssignmentsRequestTypedDict,
        ListMemberAssignmentsResponse,
        ListMemberAssignmentsResponseTypedDict,
    )
    from .listmodelscount import (
        ListModelsCountGlobals,
        ListModelsCountGlobalsTypedDict,
        ListModelsCountRequest,
        ListModelsCountRequestTypedDict,
    )
    from .listmodelsuser import (
        ListModelsUserGlobals,
        ListModelsUserGlobalsTypedDict,
        ListModelsUserRequest,
        ListModelsUserRequestTypedDict,
        ListModelsUserSecurity,
        ListModelsUserSecurityTypedDict,
    )
    from .listproviders import (
        Datacenter,
        Headquarters,
        ListProvidersData,
        ListProvidersDataTypedDict,
        ListProvidersGlobals,
        ListProvidersGlobalsTypedDict,
        ListProvidersRequest,
        ListProvidersRequestTypedDict,
        ListProvidersResponse,
        ListProvidersResponseTypedDict,
    )
    from .sendchatcompletionrequest import (
        SendChatCompletionRequestGlobals,
        SendChatCompletionRequestGlobalsTypedDict,
        SendChatCompletionRequestRequest,
        SendChatCompletionRequestRequestTypedDict,
        SendChatCompletionRequestResponse,
        SendChatCompletionRequestResponseBody,
        SendChatCompletionRequestResponseBodyTypedDict,
        SendChatCompletionRequestResponseTypedDict,
    )
    from .updateguardrail import (
        UpdateGuardrailData,
        UpdateGuardrailDataTypedDict,
        UpdateGuardrailGlobals,
        UpdateGuardrailGlobalsTypedDict,
        UpdateGuardrailRequest,
        UpdateGuardrailRequestBody,
        UpdateGuardrailRequestBodyTypedDict,
        UpdateGuardrailRequestTypedDict,
        UpdateGuardrailResetIntervalRequest,
        UpdateGuardrailResetIntervalResponse,
        UpdateGuardrailResponse,
        UpdateGuardrailResponseTypedDict,
    )
    from .updatekeys import (
        UpdateKeysData,
        UpdateKeysDataTypedDict,
        UpdateKeysGlobals,
        UpdateKeysGlobalsTypedDict,
        UpdateKeysLimitReset,
        UpdateKeysRequest,
        UpdateKeysRequestBody,
        UpdateKeysRequestBodyTypedDict,
        UpdateKeysRequestTypedDict,
        UpdateKeysResponse,
        UpdateKeysResponseTypedDict,
    )

__all__ = [
    "APIType",
    "BulkAssignKeysToGuardrailGlobals",
    "BulkAssignKeysToGuardrailGlobalsTypedDict",
    "BulkAssignKeysToGuardrailRequest",
    "BulkAssignKeysToGuardrailRequestBody",
    "BulkAssignKeysToGuardrailRequestBodyTypedDict",
    "BulkAssignKeysToGuardrailRequestTypedDict",
    "BulkAssignKeysToGuardrailResponse",
    "BulkAssignKeysToGuardrailResponseTypedDict",
    "BulkAssignMembersToGuardrailGlobals",
    "BulkAssignMembersToGuardrailGlobalsTypedDict",
    "BulkAssignMembersToGuardrailRequest",
    "BulkAssignMembersToGuardrailRequestBody",
    "BulkAssignMembersToGuardrailRequestBodyTypedDict",
    "BulkAssignMembersToGuardrailRequestTypedDict",
    "BulkAssignMembersToGuardrailResponse",
    "BulkAssignMembersToGuardrailResponseTypedDict",
    "BulkUnassignKeysFromGuardrailGlobals",
    "BulkUnassignKeysFromGuardrailGlobalsTypedDict",
    "BulkUnassignKeysFromGuardrailRequest",
    "BulkUnassignKeysFromGuardrailRequestBody",
    "BulkUnassignKeysFromGuardrailRequestBodyTypedDict",
    "BulkUnassignKeysFromGuardrailRequestTypedDict",
    "BulkUnassignKeysFromGuardrailResponse",
    "BulkUnassignKeysFromGuardrailResponseTypedDict",
    "BulkUnassignMembersFromGuardrailGlobals",
    "BulkUnassignMembersFromGuardrailGlobalsTypedDict",
    "BulkUnassignMembersFromGuardrailRequest",
    "BulkUnassignMembersFromGuardrailRequestBody",
    "BulkUnassignMembersFromGuardrailRequestBodyTypedDict",
    "BulkUnassignMembersFromGuardrailRequestTypedDict",
    "BulkUnassignMembersFromGuardrailResponse",
    "BulkUnassignMembersFromGuardrailResponseTypedDict",
    "CallData",
    "CallDataTypedDict",
    "Category",
    "Content",
    "ContentImageURL",
    "ContentImageURLTypedDict",
    "ContentText",
    "ContentTextTypedDict",
    "ContentTypedDict",
    "CreateAuthKeysCodeCodeChallengeMethod",
    "CreateAuthKeysCodeData",
    "CreateAuthKeysCodeDataTypedDict",
    "CreateAuthKeysCodeGlobals",
    "CreateAuthKeysCodeGlobalsTypedDict",
    "CreateAuthKeysCodeRequest",
    "CreateAuthKeysCodeRequestBody",
    "CreateAuthKeysCodeRequestBodyTypedDict",
    "CreateAuthKeysCodeRequestTypedDict",
    "CreateAuthKeysCodeResponse",
    "CreateAuthKeysCodeResponseTypedDict",
    "CreateCoinbaseChargeData",
    "CreateCoinbaseChargeDataTypedDict",
    "CreateCoinbaseChargeGlobals",
    "CreateCoinbaseChargeGlobalsTypedDict",
    "CreateCoinbaseChargeRequest",
    "CreateCoinbaseChargeRequestTypedDict",
    "CreateCoinbaseChargeResponse",
    "CreateCoinbaseChargeResponseTypedDict",
    "CreateCoinbaseChargeSecurity",
    "CreateCoinbaseChargeSecurityTypedDict",
    "CreateEmbeddingsData",
    "CreateEmbeddingsDataTypedDict",
    "CreateEmbeddingsGlobals",
    "CreateEmbeddingsGlobalsTypedDict",
    "CreateEmbeddingsRequest",
    "CreateEmbeddingsRequestBody",
    "CreateEmbeddingsRequestBodyTypedDict",
    "CreateEmbeddingsRequestTypedDict",
    "CreateEmbeddingsResponse",
    "CreateEmbeddingsResponseBody",
    "CreateEmbeddingsResponseBodyTypedDict",
    "CreateEmbeddingsResponseTypedDict",
    "CreateGuardrailData",
    "CreateGuardrailDataTypedDict",
    "CreateGuardrailGlobals",
    "CreateGuardrailGlobalsTypedDict",
    "CreateGuardrailRequest",
    "CreateGuardrailRequestBody",
    "CreateGuardrailRequestBodyTypedDict",
    "CreateGuardrailRequestTypedDict",
    "CreateGuardrailResetIntervalRequest",
    "CreateGuardrailResetIntervalResponse",
    "CreateGuardrailResponse",
    "CreateGuardrailResponseTypedDict",
    "CreateKeysData",
    "CreateKeysDataTypedDict",
    "CreateKeysGlobals",
    "CreateKeysGlobalsTypedDict",
    "CreateKeysLimitReset",
    "CreateKeysRequest",
    "CreateKeysRequestBody",
    "CreateKeysRequestBodyTypedDict",
    "CreateKeysRequestTypedDict",
    "CreateKeysResponse",
    "CreateKeysResponseTypedDict",
    "CreateResponsesGlobals",
    "CreateResponsesGlobalsTypedDict",
    "CreateResponsesRequest",
    "CreateResponsesRequestTypedDict",
    "CreateResponsesResponse",
    "CreateResponsesResponseBody",
    "CreateResponsesResponseBodyTypedDict",
    "CreateResponsesResponseTypedDict",
    "Datacenter",
    "DeleteGuardrailGlobals",
    "DeleteGuardrailGlobalsTypedDict",
    "DeleteGuardrailRequest",
    "DeleteGuardrailRequestTypedDict",
    "DeleteGuardrailResponse",
    "DeleteGuardrailResponseTypedDict",
    "DeleteKeysGlobals",
    "DeleteKeysGlobalsTypedDict",
    "DeleteKeysRequest",
    "DeleteKeysRequestTypedDict",
    "DeleteKeysResponse",
    "DeleteKeysResponseTypedDict",
    "Embedding",
    "EmbeddingTypedDict",
    "EncodingFormat",
    "ExchangeAuthCodeForAPIKeyCodeChallengeMethod",
    "ExchangeAuthCodeForAPIKeyGlobals",
    "ExchangeAuthCodeForAPIKeyGlobalsTypedDict",
    "ExchangeAuthCodeForAPIKeyRequest",
    "ExchangeAuthCodeForAPIKeyRequestBody",
    "ExchangeAuthCodeForAPIKeyRequestBodyTypedDict",
    "ExchangeAuthCodeForAPIKeyRequestTypedDict",
    "ExchangeAuthCodeForAPIKeyResponse",
    "ExchangeAuthCodeForAPIKeyResponseTypedDict",
    "GetCreditsData",
    "GetCreditsDataTypedDict",
    "GetCreditsGlobals",
    "GetCreditsGlobalsTypedDict",
    "GetCreditsRequest",
    "GetCreditsRequestTypedDict",
    "GetCreditsResponse",
    "GetCreditsResponseTypedDict",
    "GetCurrentKeyData",
    "GetCurrentKeyDataTypedDict",
    "GetCurrentKeyGlobals",
    "GetCurrentKeyGlobalsTypedDict",
    "GetCurrentKeyRequest",
    "GetCurrentKeyRequestTypedDict",
    "GetCurrentKeyResponse",
    "GetCurrentKeyResponseTypedDict",
    "GetGenerationData",
    "GetGenerationDataTypedDict",
    "GetGenerationGlobals",
    "GetGenerationGlobalsTypedDict",
    "GetGenerationRequest",
    "GetGenerationRequestTypedDict",
    "GetGenerationResponse",
    "GetGenerationResponseTypedDict",
    "GetGuardrailData",
    "GetGuardrailDataTypedDict",
    "GetGuardrailGlobals",
    "GetGuardrailGlobalsTypedDict",
    "GetGuardrailRequest",
    "GetGuardrailRequestTypedDict",
    "GetGuardrailResetInterval",
    "GetGuardrailResponse",
    "GetGuardrailResponseTypedDict",
    "GetKeyData",
    "GetKeyDataTypedDict",
    "GetKeyGlobals",
    "GetKeyGlobalsTypedDict",
    "GetKeyRequest",
    "GetKeyRequestTypedDict",
    "GetKeyResponse",
    "GetKeyResponseTypedDict",
    "GetModelsGlobals",
    "GetModelsGlobalsTypedDict",
    "GetModelsRequest",
    "GetModelsRequestTypedDict",
    "GetUserActivityGlobals",
    "GetUserActivityGlobalsTypedDict",
    "GetUserActivityRequest",
    "GetUserActivityRequestTypedDict",
    "GetUserActivityResponse",
    "GetUserActivityResponseTypedDict",
    "Headquarters",
    "ImageURL",
    "ImageURLTypedDict",
    "Input",
    "InputTypedDict",
    "InputUnion",
    "InputUnionTypedDict",
    "ListData",
    "ListDataTypedDict",
    "ListEmbeddingsModelsGlobals",
    "ListEmbeddingsModelsGlobalsTypedDict",
    "ListEmbeddingsModelsRequest",
    "ListEmbeddingsModelsRequestTypedDict",
    "ListEndpointsGlobals",
    "ListEndpointsGlobalsTypedDict",
    "ListEndpointsRequest",
    "ListEndpointsRequestTypedDict",
    "ListEndpointsResponse",
    "ListEndpointsResponseTypedDict",
    "ListEndpointsZdrGlobals",
    "ListEndpointsZdrGlobalsTypedDict",
    "ListEndpointsZdrRequest",
    "ListEndpointsZdrRequestTypedDict",
    "ListEndpointsZdrResponse",
    "ListEndpointsZdrResponseTypedDict",
    "ListGlobals",
    "ListGlobalsTypedDict",
    "ListGuardrailKeyAssignmentsData",
    "ListGuardrailKeyAssignmentsDataTypedDict",
    "ListGuardrailKeyAssignmentsGlobals",
    "ListGuardrailKeyAssignmentsGlobalsTypedDict",
    "ListGuardrailKeyAssignmentsRequest",
    "ListGuardrailKeyAssignmentsRequestTypedDict",
    "ListGuardrailKeyAssignmentsResponse",
    "ListGuardrailKeyAssignmentsResponseTypedDict",
    "ListGuardrailMemberAssignmentsData",
    "ListGuardrailMemberAssignmentsDataTypedDict",
    "ListGuardrailMemberAssignmentsGlobals",
    "ListGuardrailMemberAssignmentsGlobalsTypedDict",
    "ListGuardrailMemberAssignmentsRequest",
    "ListGuardrailMemberAssignmentsRequestTypedDict",
    "ListGuardrailMemberAssignmentsResponse",
    "ListGuardrailMemberAssignmentsResponseTypedDict",
    "ListGuardrailsData",
    "ListGuardrailsDataTypedDict",
    "ListGuardrailsGlobals",
    "ListGuardrailsGlobalsTypedDict",
    "ListGuardrailsRequest",
    "ListGuardrailsRequestTypedDict",
    "ListGuardrailsResetInterval",
    "ListGuardrailsResponse",
    "ListGuardrailsResponseTypedDict",
    "ListKeyAssignmentsData",
    "ListKeyAssignmentsDataTypedDict",
    "ListKeyAssignmentsGlobals",
    "ListKeyAssignmentsGlobalsTypedDict",
    "ListKeyAssignmentsRequest",
    "ListKeyAssignmentsRequestTypedDict",
    "ListKeyAssignmentsResponse",
    "ListKeyAssignmentsResponseTypedDict",
    "ListMemberAssignmentsData",
    "ListMemberAssignmentsDataTypedDict",
    "ListMemberAssignmentsGlobals",
    "ListMemberAssignmentsGlobalsTypedDict",
    "ListMemberAssignmentsRequest",
    "ListMemberAssignmentsRequestTypedDict",
    "ListMemberAssignmentsResponse",
    "ListMemberAssignmentsResponseTypedDict",
    "ListModelsCountGlobals",
    "ListModelsCountGlobalsTypedDict",
    "ListModelsCountRequest",
    "ListModelsCountRequestTypedDict",
    "ListModelsUserGlobals",
    "ListModelsUserGlobalsTypedDict",
    "ListModelsUserRequest",
    "ListModelsUserRequestTypedDict",
    "ListModelsUserSecurity",
    "ListModelsUserSecurityTypedDict",
    "ListProvidersData",
    "ListProvidersDataTypedDict",
    "ListProvidersGlobals",
    "ListProvidersGlobalsTypedDict",
    "ListProvidersRequest",
    "ListProvidersRequestTypedDict",
    "ListProvidersResponse",
    "ListProvidersResponseTypedDict",
    "ListRequest",
    "ListRequestTypedDict",
    "ListResponse",
    "ListResponseTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "Object",
    "ObjectEmbedding",
    "ProviderName",
    "ProviderResponse",
    "ProviderResponseTypedDict",
    "RateLimit",
    "RateLimitTypedDict",
    "SendChatCompletionRequestGlobals",
    "SendChatCompletionRequestGlobalsTypedDict",
    "SendChatCompletionRequestRequest",
    "SendChatCompletionRequestRequestTypedDict",
    "SendChatCompletionRequestResponse",
    "SendChatCompletionRequestResponseBody",
    "SendChatCompletionRequestResponseBodyTypedDict",
    "SendChatCompletionRequestResponseTypedDict",
    "TransferIntent",
    "TransferIntentTypedDict",
    "TypeImageURL",
    "TypeText",
    "UpdateGuardrailData",
    "UpdateGuardrailDataTypedDict",
    "UpdateGuardrailGlobals",
    "UpdateGuardrailGlobalsTypedDict",
    "UpdateGuardrailRequest",
    "UpdateGuardrailRequestBody",
    "UpdateGuardrailRequestBodyTypedDict",
    "UpdateGuardrailRequestTypedDict",
    "UpdateGuardrailResetIntervalRequest",
    "UpdateGuardrailResetIntervalResponse",
    "UpdateGuardrailResponse",
    "UpdateGuardrailResponseTypedDict",
    "UpdateKeysData",
    "UpdateKeysDataTypedDict",
    "UpdateKeysGlobals",
    "UpdateKeysGlobalsTypedDict",
    "UpdateKeysLimitReset",
    "UpdateKeysRequest",
    "UpdateKeysRequestBody",
    "UpdateKeysRequestBodyTypedDict",
    "UpdateKeysRequestTypedDict",
    "UpdateKeysResponse",
    "UpdateKeysResponseTypedDict",
    "Usage",
    "UsageLimitType",
    "UsageTypedDict",
    "Web3Data",
    "Web3DataTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "BulkAssignKeysToGuardrailGlobals": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailGlobalsTypedDict": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailRequest": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailRequestBody": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailRequestBodyTypedDict": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailRequestTypedDict": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailResponse": ".bulkassignkeystoguardrail",
    "BulkAssignKeysToGuardrailResponseTypedDict": ".bulkassignkeystoguardrail",
    "BulkAssignMembersToGuardrailGlobals": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailGlobalsTypedDict": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailRequest": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailRequestBody": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailRequestBodyTypedDict": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailRequestTypedDict": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailResponse": ".bulkassignmemberstoguardrail",
    "BulkAssignMembersToGuardrailResponseTypedDict": ".bulkassignmemberstoguardrail",
    "BulkUnassignKeysFromGuardrailGlobals": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailGlobalsTypedDict": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailRequest": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailRequestBody": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailRequestBodyTypedDict": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailRequestTypedDict": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailResponse": ".bulkunassignkeysfromguardrail",
    "BulkUnassignKeysFromGuardrailResponseTypedDict": ".bulkunassignkeysfromguardrail",
    "BulkUnassignMembersFromGuardrailGlobals": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailGlobalsTypedDict": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailRequest": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailRequestBody": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailRequestBodyTypedDict": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailRequestTypedDict": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailResponse": ".bulkunassignmembersfromguardrail",
    "BulkUnassignMembersFromGuardrailResponseTypedDict": ".bulkunassignmembersfromguardrail",
    "CreateAuthKeysCodeCodeChallengeMethod": ".createauthkeyscode",
    "CreateAuthKeysCodeData": ".createauthkeyscode",
    "CreateAuthKeysCodeDataTypedDict": ".createauthkeyscode",
    "CreateAuthKeysCodeGlobals": ".createauthkeyscode",
    "CreateAuthKeysCodeGlobalsTypedDict": ".createauthkeyscode",
    "CreateAuthKeysCodeRequest": ".createauthkeyscode",
    "CreateAuthKeysCodeRequestBody": ".createauthkeyscode",
    "CreateAuthKeysCodeRequestBodyTypedDict": ".createauthkeyscode",
    "CreateAuthKeysCodeRequestTypedDict": ".createauthkeyscode",
    "CreateAuthKeysCodeResponse": ".createauthkeyscode",
    "CreateAuthKeysCodeResponseTypedDict": ".createauthkeyscode",
    "UsageLimitType": ".createauthkeyscode",
    "CallData": ".createcoinbasecharge",
    "CallDataTypedDict": ".createcoinbasecharge",
    "CreateCoinbaseChargeData": ".createcoinbasecharge",
    "CreateCoinbaseChargeDataTypedDict": ".createcoinbasecharge",
    "CreateCoinbaseChargeGlobals": ".createcoinbasecharge",
    "CreateCoinbaseChargeGlobalsTypedDict": ".createcoinbasecharge",
    "CreateCoinbaseChargeRequest": ".createcoinbasecharge",
    "CreateCoinbaseChargeRequestTypedDict": ".createcoinbasecharge",
    "CreateCoinbaseChargeResponse": ".createcoinbasecharge",
    "CreateCoinbaseChargeResponseTypedDict": ".createcoinbasecharge",
    "CreateCoinbaseChargeSecurity": ".createcoinbasecharge",
    "CreateCoinbaseChargeSecurityTypedDict": ".createcoinbasecharge",
    "Metadata": ".createcoinbasecharge",
    "MetadataTypedDict": ".createcoinbasecharge",
    "TransferIntent": ".createcoinbasecharge",
    "TransferIntentTypedDict": ".createcoinbasecharge",
    "Web3Data": ".createcoinbasecharge",
    "Web3DataTypedDict": ".createcoinbasecharge",
    "Content": ".createembeddings",
    "ContentImageURL": ".createembeddings",
    "ContentImageURLTypedDict": ".createembeddings",
    "ContentText": ".createembeddings",
    "ContentTextTypedDict": ".createembeddings",
    "ContentTypedDict": ".createembeddings",
    "CreateEmbeddingsData": ".createembeddings",
    "CreateEmbeddingsDataTypedDict": ".createembeddings",
    "CreateEmbeddingsGlobals": ".createembeddings",
    "CreateEmbeddingsGlobalsTypedDict": ".createembeddings",
    "CreateEmbeddingsRequest": ".createembeddings",
    "CreateEmbeddingsRequestBody": ".createembeddings",
    "CreateEmbeddingsRequestBodyTypedDict": ".createembeddings",
    "CreateEmbeddingsRequestTypedDict": ".createembeddings",
    "CreateEmbeddingsResponse": ".createembeddings",
    "CreateEmbeddingsResponseBody": ".createembeddings",
    "CreateEmbeddingsResponseBodyTypedDict": ".createembeddings",
    "CreateEmbeddingsResponseTypedDict": ".createembeddings",
    "Embedding": ".createembeddings",
    "EmbeddingTypedDict": ".createembeddings",
    "EncodingFormat": ".createembeddings",
    "ImageURL": ".createembeddings",
    "ImageURLTypedDict": ".createembeddings",
    "Input": ".createembeddings",
    "InputTypedDict": ".createembeddings",
    "InputUnion": ".createembeddings",
    "InputUnionTypedDict": ".createembeddings",
    "Object": ".createembeddings",
    "ObjectEmbedding": ".createembeddings",
    "TypeImageURL": ".createembeddings",
    "TypeText": ".createembeddings",
    "Usage": ".createembeddings",
    "UsageTypedDict": ".createembeddings",
    "CreateGuardrailData": ".createguardrail",
    "CreateGuardrailDataTypedDict": ".createguardrail",
    "CreateGuardrailGlobals": ".createguardrail",
    "CreateGuardrailGlobalsTypedDict": ".createguardrail",
    "CreateGuardrailRequest": ".createguardrail",
    "CreateGuardrailRequestBody": ".createguardrail",
    "CreateGuardrailRequestBodyTypedDict": ".createguardrail",
    "CreateGuardrailRequestTypedDict": ".createguardrail",
    "CreateGuardrailResetIntervalRequest": ".createguardrail",
    "CreateGuardrailResetIntervalResponse": ".createguardrail",
    "CreateGuardrailResponse": ".createguardrail",
    "CreateGuardrailResponseTypedDict": ".createguardrail",
    "CreateKeysData": ".createkeys",
    "CreateKeysDataTypedDict": ".createkeys",
    "CreateKeysGlobals": ".createkeys",
    "CreateKeysGlobalsTypedDict": ".createkeys",
    "CreateKeysLimitReset": ".createkeys",
    "CreateKeysRequest": ".createkeys",
    "CreateKeysRequestBody": ".createkeys",
    "CreateKeysRequestBodyTypedDict": ".createkeys",
    "CreateKeysRequestTypedDict": ".createkeys",
    "CreateKeysResponse": ".createkeys",
    "CreateKeysResponseTypedDict": ".createkeys",
    "CreateResponsesGlobals": ".createresponses",
    "CreateResponsesGlobalsTypedDict": ".createresponses",
    "CreateResponsesRequest": ".createresponses",
    "CreateResponsesRequestTypedDict": ".createresponses",
    "CreateResponsesResponse": ".createresponses",
    "CreateResponsesResponseBody": ".createresponses",
    "CreateResponsesResponseBodyTypedDict": ".createresponses",
    "CreateResponsesResponseTypedDict": ".createresponses",
    "DeleteGuardrailGlobals": ".deleteguardrail",
    "DeleteGuardrailGlobalsTypedDict": ".deleteguardrail",
    "DeleteGuardrailRequest": ".deleteguardrail",
    "DeleteGuardrailRequestTypedDict": ".deleteguardrail",
    "DeleteGuardrailResponse": ".deleteguardrail",
    "DeleteGuardrailResponseTypedDict": ".deleteguardrail",
    "DeleteKeysGlobals": ".deletekeys",
    "DeleteKeysGlobalsTypedDict": ".deletekeys",
    "DeleteKeysRequest": ".deletekeys",
    "DeleteKeysRequestTypedDict": ".deletekeys",
    "DeleteKeysResponse": ".deletekeys",
    "DeleteKeysResponseTypedDict": ".deletekeys",
    "ExchangeAuthCodeForAPIKeyCodeChallengeMethod": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyGlobals": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyGlobalsTypedDict": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyRequest": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyRequestBody": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyRequestBodyTypedDict": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyRequestTypedDict": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyResponse": ".exchangeauthcodeforapikey",
    "ExchangeAuthCodeForAPIKeyResponseTypedDict": ".exchangeauthcodeforapikey",
    "GetCreditsData": ".getcredits",
    "GetCreditsDataTypedDict": ".getcredits",
    "GetCreditsGlobals": ".getcredits",
    "GetCreditsGlobalsTypedDict": ".getcredits",
    "GetCreditsRequest": ".getcredits",
    "GetCreditsRequestTypedDict": ".getcredits",
    "GetCreditsResponse": ".getcredits",
    "GetCreditsResponseTypedDict": ".getcredits",
    "GetCurrentKeyData": ".getcurrentkey",
    "GetCurrentKeyDataTypedDict": ".getcurrentkey",
    "GetCurrentKeyGlobals": ".getcurrentkey",
    "GetCurrentKeyGlobalsTypedDict": ".getcurrentkey",
    "GetCurrentKeyRequest": ".getcurrentkey",
    "GetCurrentKeyRequestTypedDict": ".getcurrentkey",
    "GetCurrentKeyResponse": ".getcurrentkey",
    "GetCurrentKeyResponseTypedDict": ".getcurrentkey",
    "RateLimit": ".getcurrentkey",
    "RateLimitTypedDict": ".getcurrentkey",
    "APIType": ".getgeneration",
    "GetGenerationData": ".getgeneration",
    "GetGenerationDataTypedDict": ".getgeneration",
    "GetGenerationGlobals": ".getgeneration",
    "GetGenerationGlobalsTypedDict": ".getgeneration",
    "GetGenerationRequest": ".getgeneration",
    "GetGenerationRequestTypedDict": ".getgeneration",
    "GetGenerationResponse": ".getgeneration",
    "GetGenerationResponseTypedDict": ".getgeneration",
    "ProviderName": ".getgeneration",
    "ProviderResponse": ".getgeneration",
    "ProviderResponseTypedDict": ".getgeneration",
    "GetGuardrailData": ".getguardrail",
    "GetGuardrailDataTypedDict": ".getguardrail",
    "GetGuardrailGlobals": ".getguardrail",
    "GetGuardrailGlobalsTypedDict": ".getguardrail",
    "GetGuardrailRequest": ".getguardrail",
    "GetGuardrailRequestTypedDict": ".getguardrail",
    "GetGuardrailResetInterval": ".getguardrail",
    "GetGuardrailResponse": ".getguardrail",
    "GetGuardrailResponseTypedDict": ".getguardrail",
    "GetKeyData": ".getkey",
    "GetKeyDataTypedDict": ".getkey",
    "GetKeyGlobals": ".getkey",
    "GetKeyGlobalsTypedDict": ".getkey",
    "GetKeyRequest": ".getkey",
    "GetKeyRequestTypedDict": ".getkey",
    "GetKeyResponse": ".getkey",
    "GetKeyResponseTypedDict": ".getkey",
    "Category": ".getmodels",
    "GetModelsGlobals": ".getmodels",
    "GetModelsGlobalsTypedDict": ".getmodels",
    "GetModelsRequest": ".getmodels",
    "GetModelsRequestTypedDict": ".getmodels",
    "GetUserActivityGlobals": ".getuseractivity",
    "GetUserActivityGlobalsTypedDict": ".getuseractivity",
    "GetUserActivityRequest": ".getuseractivity",
    "GetUserActivityRequestTypedDict": ".getuseractivity",
    "GetUserActivityResponse": ".getuseractivity",
    "GetUserActivityResponseTypedDict": ".getuseractivity",
    "ListData": ".list",
    "ListDataTypedDict": ".list",
    "ListGlobals": ".list",
    "ListGlobalsTypedDict": ".list",
    "ListRequest": ".list",
    "ListRequestTypedDict": ".list",
    "ListResponse": ".list",
    "ListResponseTypedDict": ".list",
    "ListEmbeddingsModelsGlobals": ".listembeddingsmodels",
    "ListEmbeddingsModelsGlobalsTypedDict": ".listembeddingsmodels",
    "ListEmbeddingsModelsRequest": ".listembeddingsmodels",
    "ListEmbeddingsModelsRequestTypedDict": ".listembeddingsmodels",
    "ListEndpointsGlobals": ".listendpoints",
    "ListEndpointsGlobalsTypedDict": ".listendpoints",
    "ListEndpointsRequest": ".listendpoints",
    "ListEndpointsRequestTypedDict": ".listendpoints",
    "ListEndpointsResponse": ".listendpoints",
    "ListEndpointsResponseTypedDict": ".listendpoints",
    "ListEndpointsZdrGlobals": ".listendpointszdr",
    "ListEndpointsZdrGlobalsTypedDict": ".listendpointszdr",
    "ListEndpointsZdrRequest": ".listendpointszdr",
    "ListEndpointsZdrRequestTypedDict": ".listendpointszdr",
    "ListEndpointsZdrResponse": ".listendpointszdr",
    "ListEndpointsZdrResponseTypedDict": ".listendpointszdr",
    "ListGuardrailKeyAssignmentsData": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsDataTypedDict": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsGlobals": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsGlobalsTypedDict": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsRequest": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsRequestTypedDict": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsResponse": ".listguardrailkeyassignments",
    "ListGuardrailKeyAssignmentsResponseTypedDict": ".listguardrailkeyassignments",
    "ListGuardrailMemberAssignmentsData": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsDataTypedDict": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsGlobals": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsGlobalsTypedDict": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsRequest": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsRequestTypedDict": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsResponse": ".listguardrailmemberassignments",
    "ListGuardrailMemberAssignmentsResponseTypedDict": ".listguardrailmemberassignments",
    "ListGuardrailsData": ".listguardrails",
    "ListGuardrailsDataTypedDict": ".listguardrails",
    "ListGuardrailsGlobals": ".listguardrails",
    "ListGuardrailsGlobalsTypedDict": ".listguardrails",
    "ListGuardrailsRequest": ".listguardrails",
    "ListGuardrailsRequestTypedDict": ".listguardrails",
    "ListGuardrailsResetInterval": ".listguardrails",
    "ListGuardrailsResponse": ".listguardrails",
    "ListGuardrailsResponseTypedDict": ".listguardrails",
    "ListKeyAssignmentsData": ".listkeyassignments",
    "ListKeyAssignmentsDataTypedDict": ".listkeyassignments",
    "ListKeyAssignmentsGlobals": ".listkeyassignments",
    "ListKeyAssignmentsGlobalsTypedDict": ".listkeyassignments",
    "ListKeyAssignmentsRequest": ".listkeyassignments",
    "ListKeyAssignmentsRequestTypedDict": ".listkeyassignments",
    "ListKeyAssignmentsResponse": ".listkeyassignments",
    "ListKeyAssignmentsResponseTypedDict": ".listkeyassignments",
    "ListMemberAssignmentsData": ".listmemberassignments",
    "ListMemberAssignmentsDataTypedDict": ".listmemberassignments",
    "ListMemberAssignmentsGlobals": ".listmemberassignments",
    "ListMemberAssignmentsGlobalsTypedDict": ".listmemberassignments",
    "ListMemberAssignmentsRequest": ".listmemberassignments",
    "ListMemberAssignmentsRequestTypedDict": ".listmemberassignments",
    "ListMemberAssignmentsResponse": ".listmemberassignments",
    "ListMemberAssignmentsResponseTypedDict": ".listmemberassignments",
    "ListModelsCountGlobals": ".listmodelscount",
    "ListModelsCountGlobalsTypedDict": ".listmodelscount",
    "ListModelsCountRequest": ".listmodelscount",
    "ListModelsCountRequestTypedDict": ".listmodelscount",
    "ListModelsUserGlobals": ".listmodelsuser",
    "ListModelsUserGlobalsTypedDict": ".listmodelsuser",
    "ListModelsUserRequest": ".listmodelsuser",
    "ListModelsUserRequestTypedDict": ".listmodelsuser",
    "ListModelsUserSecurity": ".listmodelsuser",
    "ListModelsUserSecurityTypedDict": ".listmodelsuser",
    "Datacenter": ".listproviders",
    "Headquarters": ".listproviders",
    "ListProvidersData": ".listproviders",
    "ListProvidersDataTypedDict": ".listproviders",
    "ListProvidersGlobals": ".listproviders",
    "ListProvidersGlobalsTypedDict": ".listproviders",
    "ListProvidersRequest": ".listproviders",
    "ListProvidersRequestTypedDict": ".listproviders",
    "ListProvidersResponse": ".listproviders",
    "ListProvidersResponseTypedDict": ".listproviders",
    "SendChatCompletionRequestGlobals": ".sendchatcompletionrequest",
    "SendChatCompletionRequestGlobalsTypedDict": ".sendchatcompletionrequest",
    "SendChatCompletionRequestRequest": ".sendchatcompletionrequest",
    "SendChatCompletionRequestRequestTypedDict": ".sendchatcompletionrequest",
    "SendChatCompletionRequestResponse": ".sendchatcompletionrequest",
    "SendChatCompletionRequestResponseBody": ".sendchatcompletionrequest",
    "SendChatCompletionRequestResponseBodyTypedDict": ".sendchatcompletionrequest",
    "SendChatCompletionRequestResponseTypedDict": ".sendchatcompletionrequest",
    "UpdateGuardrailData": ".updateguardrail",
    "UpdateGuardrailDataTypedDict": ".updateguardrail",
    "UpdateGuardrailGlobals": ".updateguardrail",
    "UpdateGuardrailGlobalsTypedDict": ".updateguardrail",
    "UpdateGuardrailRequest": ".updateguardrail",
    "UpdateGuardrailRequestBody": ".updateguardrail",
    "UpdateGuardrailRequestBodyTypedDict": ".updateguardrail",
    "UpdateGuardrailRequestTypedDict": ".updateguardrail",
    "UpdateGuardrailResetIntervalRequest": ".updateguardrail",
    "UpdateGuardrailResetIntervalResponse": ".updateguardrail",
    "UpdateGuardrailResponse": ".updateguardrail",
    "UpdateGuardrailResponseTypedDict": ".updateguardrail",
    "UpdateKeysData": ".updatekeys",
    "UpdateKeysDataTypedDict": ".updatekeys",
    "UpdateKeysGlobals": ".updatekeys",
    "UpdateKeysGlobalsTypedDict": ".updatekeys",
    "UpdateKeysLimitReset": ".updatekeys",
    "UpdateKeysRequest": ".updatekeys",
    "UpdateKeysRequestBody": ".updatekeys",
    "UpdateKeysRequestBodyTypedDict": ".updatekeys",
    "UpdateKeysRequestTypedDict": ".updatekeys",
    "UpdateKeysResponse": ".updatekeys",
    "UpdateKeysResponseTypedDict": ".updatekeys",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
