"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .videoinput import VideoInput, VideoInputTypedDict
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatMessageContentItemVideoType = Literal["video_url",]


class ChatMessageContentItemVideoTypedDict(TypedDict):
    r"""Video input content part"""

    type: ChatMessageContentItemVideoType
    video_url: VideoInputTypedDict
    r"""Video input object"""


class ChatMessageContentItemVideo(BaseModel):
    r"""Video input content part"""

    type: ChatMessageContentItemVideoType

    video_url: VideoInput
    r"""Video input object"""
