"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


ChatMessageContentItemImageType = Literal["image_url",]


ChatMessageContentItemImageDetail = Union[
    Literal[
        "auto",
        "low",
        "high",
    ],
    UnrecognizedStr,
]
r"""Image detail level for vision models"""


class ChatMessageContentItemImageImageURLTypedDict(TypedDict):
    url: str
    r"""URL of the image (data: URLs supported)"""
    detail: NotRequired[ChatMessageContentItemImageDetail]
    r"""Image detail level for vision models"""


class ChatMessageContentItemImageImageURL(BaseModel):
    url: str
    r"""URL of the image (data: URLs supported)"""

    detail: Annotated[
        Optional[ChatMessageContentItemImageDetail],
        PlainValidator(validate_open_enum(False)),
    ] = None
    r"""Image detail level for vision models"""


class ChatMessageContentItemImageTypedDict(TypedDict):
    r"""Image content part for vision models"""

    type: ChatMessageContentItemImageType
    image_url: ChatMessageContentItemImageImageURLTypedDict


class ChatMessageContentItemImage(BaseModel):
    r"""Image content part for vision models"""

    type: ChatMessageContentItemImageType

    image_url: ChatMessageContentItemImageImageURL
