"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class ChatAssistantImagesImageURLTypedDict(TypedDict):
    url: str
    r"""URL or base64-encoded data of the generated image"""


class ChatAssistantImagesImageURL(BaseModel):
    url: str
    r"""URL or base64-encoded data of the generated image"""


class ChatAssistantImagesTypedDict(TypedDict):
    image_url: ChatAssistantImagesImageURLTypedDict


class ChatAssistantImages(BaseModel):
    image_url: ChatAssistantImagesImageURL
