"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesLocalShellToolType = Literal["local_shell",]


class OpenResponsesLocalShellToolTypedDict(TypedDict):
    r"""Local shell tool configuration"""

    type: OpenResponsesLocalShellToolType


class OpenResponsesLocalShellTool(BaseModel):
    r"""Local shell tool configuration"""

    type: OpenResponsesLocalShellToolType
