"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


FormatTextConfigType = Literal["text",]


class FormatTextConfigTypedDict(TypedDict):
    r"""Plain text response format"""

    type: FormatTextConfigType


class FormatTextConfig(BaseModel):
    r"""Plain text response format"""

    type: FormatTextConfigType
