"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatFormatPythonConfigType = Literal["python",]


class ChatFormatPythonConfigTypedDict(TypedDict):
    r"""Python code response format"""

    type: ChatFormatPythonConfigType


class ChatFormatPythonConfig(BaseModel):
    r"""Python code response format"""

    type: ChatFormatPythonConfigType
