"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


ContextCompressionEngine = Literal["middle-out",]
r"""The compression engine to use. Defaults to \"middle-out\"."""
