"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


ProviderSort = Union[
    Literal[
        "price",
        "throughput",
        "latency",
        "exacto",
    ],
    UnrecognizedStr,
]
r"""The provider sorting strategy (price, throughput, latency)"""
