"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputfile import InputFile, InputFileTypedDict
from .inputtext import InputText, InputTextTypedDict
from .toolcallstatusenum import ToolCallStatusEnum
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_open_enum
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


FunctionCallOutputItemTypeFunctionCallOutput = Literal["function_call_output",]


OutputType = Literal["input_image",]


FunctionCallOutputItemDetail = Union[
    Literal[
        "auto",
        "high",
        "low",
    ],
    UnrecognizedStr,
]


class OutputInputImageTypedDict(TypedDict):
    r"""Image input content item"""

    type: OutputType
    detail: FunctionCallOutputItemDetail
    image_url: NotRequired[Nullable[str]]


class OutputInputImage(BaseModel):
    r"""Image input content item"""

    type: OutputType

    detail: Annotated[
        FunctionCallOutputItemDetail, PlainValidator(validate_open_enum(False))
    ]

    image_url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["image_url"]
        nullable_fields = ["image_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


FunctionCallOutputItemOutputUnion1TypedDict = TypeAliasType(
    "FunctionCallOutputItemOutputUnion1TypedDict",
    Union[InputTextTypedDict, OutputInputImageTypedDict, InputFileTypedDict],
)


FunctionCallOutputItemOutputUnion1 = Annotated[
    Union[
        Annotated[InputText, Tag("input_text")],
        Annotated[OutputInputImage, Tag("input_image")],
        Annotated[InputFile, Tag("input_file")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


FunctionCallOutputItemOutputUnion2TypedDict = TypeAliasType(
    "FunctionCallOutputItemOutputUnion2TypedDict",
    Union[str, List[FunctionCallOutputItemOutputUnion1TypedDict]],
)


FunctionCallOutputItemOutputUnion2 = TypeAliasType(
    "FunctionCallOutputItemOutputUnion2",
    Union[str, List[FunctionCallOutputItemOutputUnion1]],
)


class FunctionCallOutputItemTypedDict(TypedDict):
    r"""The output from a function call execution"""

    type: FunctionCallOutputItemTypeFunctionCallOutput
    call_id: str
    output: FunctionCallOutputItemOutputUnion2TypedDict
    id: NotRequired[Nullable[str]]
    status: NotRequired[Nullable[ToolCallStatusEnum]]


class FunctionCallOutputItem(BaseModel):
    r"""The output from a function call execution"""

    type: FunctionCallOutputItemTypeFunctionCallOutput

    call_id: str

    output: FunctionCallOutputItemOutputUnion2

    id: OptionalNullable[str] = UNSET

    status: Annotated[
        OptionalNullable[ToolCallStatusEnum], PlainValidator(validate_open_enum(False))
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "status"]
        nullable_fields = ["id", "status"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
