"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import (
    FieldMetadata,
    HeaderMetadata,
    QueryParamMetadata,
    validate_open_enum,
)
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class ListGuardrailsGlobalsTypedDict(TypedDict):
    http_referer: NotRequired[str]
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """
    x_open_router_title: NotRequired[str]
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """
    x_open_router_categories: NotRequired[str]
    r"""Comma-separated list of app categories (e.g. \"cli-agent,cloud-agent\"). Used for marketplace rankings.

    """


class ListGuardrailsGlobals(BaseModel):
    http_referer: Annotated[
        Optional[str],
        pydantic.Field(alias="HTTP-Referer"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """

    x_open_router_title: Annotated[
        Optional[str],
        pydantic.Field(alias="X-OpenRouter-Title"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """

    x_open_router_categories: Annotated[
        Optional[str],
        pydantic.Field(alias="X-OpenRouter-Categories"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Comma-separated list of app categories (e.g. \"cli-agent,cloud-agent\"). Used for marketplace rankings.

    """


class ListGuardrailsRequestTypedDict(TypedDict):
    http_referer: NotRequired[str]
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """
    x_open_router_title: NotRequired[str]
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """
    x_open_router_categories: NotRequired[str]
    r"""Comma-separated list of app categories (e.g. \"cli-agent,cloud-agent\"). Used for marketplace rankings.

    """
    offset: NotRequired[str]
    r"""Number of records to skip for pagination"""
    limit: NotRequired[str]
    r"""Maximum number of records to return (max 100)"""


class ListGuardrailsRequest(BaseModel):
    http_referer: Annotated[
        Optional[str],
        pydantic.Field(alias="HTTP-Referer"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """

    x_open_router_title: Annotated[
        Optional[str],
        pydantic.Field(alias="X-OpenRouter-Title"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """

    x_open_router_categories: Annotated[
        Optional[str],
        pydantic.Field(alias="X-OpenRouter-Categories"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Comma-separated list of app categories (e.g. \"cli-agent,cloud-agent\"). Used for marketplace rankings.

    """

    offset: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Number of records to skip for pagination"""

    limit: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Maximum number of records to return (max 100)"""


ListGuardrailsResetInterval = Union[
    Literal[
        "daily",
        "weekly",
        "monthly",
    ],
    UnrecognizedStr,
]
r"""Interval at which the limit resets (daily, weekly, monthly)"""


class ListGuardrailsDataTypedDict(TypedDict):
    id: str
    r"""Unique identifier for the guardrail"""
    name: str
    r"""Name of the guardrail"""
    created_at: str
    r"""ISO 8601 timestamp of when the guardrail was created"""
    description: NotRequired[Nullable[str]]
    r"""Description of the guardrail"""
    limit_usd: NotRequired[Nullable[float]]
    r"""Spending limit in USD"""
    reset_interval: NotRequired[Nullable[ListGuardrailsResetInterval]]
    r"""Interval at which the limit resets (daily, weekly, monthly)"""
    allowed_providers: NotRequired[Nullable[List[str]]]
    r"""List of allowed provider IDs"""
    ignored_providers: NotRequired[Nullable[List[str]]]
    r"""List of provider IDs to exclude from routing"""
    allowed_models: NotRequired[Nullable[List[str]]]
    r"""Array of model canonical_slugs (immutable identifiers)"""
    enforce_zdr: NotRequired[Nullable[bool]]
    r"""Whether to enforce zero data retention"""
    updated_at: NotRequired[Nullable[str]]
    r"""ISO 8601 timestamp of when the guardrail was last updated"""


class ListGuardrailsData(BaseModel):
    id: str
    r"""Unique identifier for the guardrail"""

    name: str
    r"""Name of the guardrail"""

    created_at: str
    r"""ISO 8601 timestamp of when the guardrail was created"""

    description: OptionalNullable[str] = UNSET
    r"""Description of the guardrail"""

    limit_usd: OptionalNullable[float] = UNSET
    r"""Spending limit in USD"""

    reset_interval: Annotated[
        OptionalNullable[ListGuardrailsResetInterval],
        PlainValidator(validate_open_enum(False)),
    ] = UNSET
    r"""Interval at which the limit resets (daily, weekly, monthly)"""

    allowed_providers: OptionalNullable[List[str]] = UNSET
    r"""List of allowed provider IDs"""

    ignored_providers: OptionalNullable[List[str]] = UNSET
    r"""List of provider IDs to exclude from routing"""

    allowed_models: OptionalNullable[List[str]] = UNSET
    r"""Array of model canonical_slugs (immutable identifiers)"""

    enforce_zdr: OptionalNullable[bool] = UNSET
    r"""Whether to enforce zero data retention"""

    updated_at: OptionalNullable[str] = UNSET
    r"""ISO 8601 timestamp of when the guardrail was last updated"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "limit_usd",
            "reset_interval",
            "allowed_providers",
            "ignored_providers",
            "allowed_models",
            "enforce_zdr",
            "updated_at",
        ]
        nullable_fields = [
            "description",
            "limit_usd",
            "reset_interval",
            "allowed_providers",
            "ignored_providers",
            "allowed_models",
            "enforce_zdr",
            "updated_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ListGuardrailsResponseTypedDict(TypedDict):
    r"""List of guardrails"""

    data: List[ListGuardrailsDataTypedDict]
    r"""List of guardrails"""
    total_count: float
    r"""Total number of guardrails"""


class ListGuardrailsResponse(BaseModel):
    r"""List of guardrails"""

    data: List[ListGuardrailsData]
    r"""List of guardrails"""

    total_count: float
    r"""Total number of guardrails"""
