"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DebugOptionsTypedDict(TypedDict):
    r"""Debug options for inspecting request transformations (streaming only)"""

    echo_upstream_body: NotRequired[bool]
    r"""If true, includes the transformed upstream request body in a debug chunk at the start of the stream. Only works with streaming mode."""


class DebugOptions(BaseModel):
    r"""Debug options for inspecting request transformations (streaming only)"""

    echo_upstream_body: Optional[bool] = None
    r"""If true, includes the transformed upstream request body in a debug chunk at the start of the stream. Only works with streaming mode."""
