"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChatCompletionAudioOutputTypedDict(TypedDict):
    r"""Audio output data or reference"""

    id: NotRequired[str]
    r"""Audio output identifier"""
    expires_at: NotRequired[float]
    r"""Audio expiration timestamp"""
    data: NotRequired[str]
    r"""Base64 encoded audio data"""
    transcript: NotRequired[str]
    r"""Audio transcript"""


class ChatCompletionAudioOutput(BaseModel):
    r"""Audio output data or reference"""

    id: Optional[str] = None
    r"""Audio output identifier"""

    expires_at: Optional[float] = None
    r"""Audio expiration timestamp"""

    data: Optional[str] = None
    r"""Base64 encoded audio data"""

    transcript: Optional[str] = None
    r"""Audio transcript"""
