"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class AssistantMessageImagesImageURLTypedDict(TypedDict):
    url: str
    r"""URL or base64-encoded data of the generated image"""


class AssistantMessageImagesImageURL(BaseModel):
    url: str
    r"""URL or base64-encoded data of the generated image"""


class AssistantMessageImagesTypedDict(TypedDict):
    image_url: AssistantMessageImagesImageURLTypedDict


class AssistantMessageImages(BaseModel):
    image_url: AssistantMessageImagesImageURL
