"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CompletionTokensDetailsTypedDict(TypedDict):
    r"""Detailed completion token usage"""

    reasoning_tokens: NotRequired[Nullable[float]]
    r"""Tokens used for reasoning"""
    audio_tokens: NotRequired[Nullable[float]]
    r"""Tokens used for audio output"""
    accepted_prediction_tokens: NotRequired[Nullable[float]]
    r"""Accepted prediction tokens"""
    rejected_prediction_tokens: NotRequired[Nullable[float]]
    r"""Rejected prediction tokens"""


class CompletionTokensDetails(BaseModel):
    r"""Detailed completion token usage"""

    reasoning_tokens: OptionalNullable[float] = UNSET
    r"""Tokens used for reasoning"""

    audio_tokens: OptionalNullable[float] = UNSET
    r"""Tokens used for audio output"""

    accepted_prediction_tokens: OptionalNullable[float] = UNSET
    r"""Accepted prediction tokens"""

    rejected_prediction_tokens: OptionalNullable[float] = UNSET
    r"""Rejected prediction tokens"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "reasoning_tokens",
            "audio_tokens",
            "accepted_prediction_tokens",
            "rejected_prediction_tokens",
        ]
        nullable_fields = [
            "reasoning_tokens",
            "audio_tokens",
            "accepted_prediction_tokens",
            "rejected_prediction_tokens",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PromptTokensDetailsTypedDict(TypedDict):
    r"""Detailed prompt token usage"""

    cached_tokens: NotRequired[float]
    r"""Cached prompt tokens"""
    cache_write_tokens: NotRequired[float]
    r"""Tokens written to cache. Only returned for models with explicit caching and cache write pricing."""
    audio_tokens: NotRequired[float]
    r"""Audio input tokens"""
    video_tokens: NotRequired[float]
    r"""Video input tokens"""


class PromptTokensDetails(BaseModel):
    r"""Detailed prompt token usage"""

    cached_tokens: Optional[float] = None
    r"""Cached prompt tokens"""

    cache_write_tokens: Optional[float] = None
    r"""Tokens written to cache. Only returned for models with explicit caching and cache write pricing."""

    audio_tokens: Optional[float] = None
    r"""Audio input tokens"""

    video_tokens: Optional[float] = None
    r"""Video input tokens"""


class ChatUsageTypedDict(TypedDict):
    r"""Token usage statistics"""

    completion_tokens: float
    r"""Number of tokens in the completion"""
    prompt_tokens: float
    r"""Number of tokens in the prompt"""
    total_tokens: float
    r"""Total number of tokens"""
    completion_tokens_details: NotRequired[Nullable[CompletionTokensDetailsTypedDict]]
    r"""Detailed completion token usage"""
    prompt_tokens_details: NotRequired[Nullable[PromptTokensDetailsTypedDict]]
    r"""Detailed prompt token usage"""


class ChatUsage(BaseModel):
    r"""Token usage statistics"""

    completion_tokens: float
    r"""Number of tokens in the completion"""

    prompt_tokens: float
    r"""Number of tokens in the prompt"""

    total_tokens: float
    r"""Total number of tokens"""

    completion_tokens_details: OptionalNullable[CompletionTokensDetails] = UNSET
    r"""Detailed completion token usage"""

    prompt_tokens_details: OptionalNullable[PromptTokensDetails] = UNSET
    r"""Detailed prompt token usage"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["completion_tokens_details", "prompt_tokens_details"]
        nullable_fields = ["completion_tokens_details", "prompt_tokens_details"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
