"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesApplyPatchToolType = Literal["apply_patch",]


class OpenResponsesApplyPatchToolTypedDict(TypedDict):
    r"""Apply patch tool configuration"""

    type: OpenResponsesApplyPatchToolType


class OpenResponsesApplyPatchTool(BaseModel):
    r"""Apply patch tool configuration"""

    type: OpenResponsesApplyPatchToolType
