"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseFormatTextPythonType = Literal["python",]


class ResponseFormatTextPythonTypedDict(TypedDict):
    r"""Python code response format"""

    type: ResponseFormatTextPythonType


class ResponseFormatTextPython(BaseModel):
    r"""Python code response format"""

    type: ResponseFormatTextPythonType
