"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


InputTextType = Literal["input_text",]


class InputTextTypedDict(TypedDict):
    r"""Text input content item"""

    type: InputTextType
    text: str


class InputText(BaseModel):
    r"""Text input content item"""

    type: InputTextType

    text: str
