"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


ChatContentImageType = Literal["image_url",]


ChatContentImageDetail = Union[
    Literal[
        "auto",
        "low",
        "high",
    ],
    UnrecognizedStr,
]
r"""Image detail level for vision models"""


class ChatContentImageImageURLTypedDict(TypedDict):
    url: str
    r"""URL of the image (data: URLs supported)"""
    detail: NotRequired[ChatContentImageDetail]
    r"""Image detail level for vision models"""


class ChatContentImageImageURL(BaseModel):
    url: str
    r"""URL of the image (data: URLs supported)"""

    detail: Annotated[
        Optional[ChatContentImageDetail], PlainValidator(validate_open_enum(False))
    ] = None
    r"""Image detail level for vision models"""


class ChatContentImageTypedDict(TypedDict):
    r"""Image content part for vision models"""

    type: ChatContentImageType
    image_url: ChatContentImageImageURLTypedDict


class ChatContentImage(BaseModel):
    r"""Image content part for vision models"""

    type: ChatContentImageType

    image_url: ChatContentImageImageURL
