"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcontentcachecontrol import (
    ChatContentCacheControl,
    ChatContentCacheControlTypedDict,
)
from openrouter.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


ChatContentTextType = Literal["text",]


class ChatContentTextTypedDict(TypedDict):
    r"""Text content part"""

    type: ChatContentTextType
    text: str
    cache_control: NotRequired[ChatContentCacheControlTypedDict]
    r"""Cache control for the content part"""


class ChatContentText(BaseModel):
    r"""Text content part"""

    type: ChatContentTextType

    text: str

    cache_control: Optional[ChatContentCacheControl] = None
    r"""Cache control for the content part"""
