"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcontentitems import ChatContentItems, ChatContentItemsTypedDict
from openrouter.types import BaseModel
from typing import List, Literal, Union
from typing_extensions import TypeAliasType, TypedDict


ChatToolMessageRole = Literal["tool",]


ChatToolMessageContentTypedDict = TypeAliasType(
    "ChatToolMessageContentTypedDict", Union[str, List[ChatContentItemsTypedDict]]
)
r"""Tool response content"""


ChatToolMessageContent = TypeAliasType(
    "ChatToolMessageContent", Union[str, List[ChatContentItems]]
)
r"""Tool response content"""


class ChatToolMessageTypedDict(TypedDict):
    r"""Tool response message"""

    role: ChatToolMessageRole
    content: ChatToolMessageContentTypedDict
    r"""Tool response content"""
    tool_call_id: str
    r"""ID of the assistant message tool call this message responds to"""


class ChatToolMessage(BaseModel):
    r"""Tool response message"""

    role: ChatToolMessageRole

    content: ChatToolMessageContent
    r"""Tool response content"""

    tool_call_id: str
    r"""ID of the assistant message tool call this message responds to"""
