"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


RefusalDeltaEventType = Literal["response.refusal.delta",]


class RefusalDeltaEventTypedDict(TypedDict):
    r"""Event emitted when a refusal delta is streamed"""

    type: RefusalDeltaEventType
    output_index: float
    item_id: str
    content_index: float
    delta: str
    sequence_number: float


class RefusalDeltaEvent(BaseModel):
    r"""Event emitted when a refusal delta is streamed"""

    type: RefusalDeltaEventType

    output_index: float

    item_id: str

    content_index: float

    delta: str

    sequence_number: float
