"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


RefusalDoneEventType = Literal["response.refusal.done",]


class RefusalDoneEventTypedDict(TypedDict):
    r"""Event emitted when refusal streaming is complete"""

    type: RefusalDoneEventType
    output_index: float
    item_id: str
    content_index: float
    refusal: str
    sequence_number: float


class RefusalDoneEvent(BaseModel):
    r"""Event emitted when refusal streaming is complete"""

    type: RefusalDoneEventType

    output_index: float

    item_id: str

    content_index: float

    refusal: str

    sequence_number: float
