"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


OutputFunctionCallItemType = Literal["function_call",]


OutputFunctionCallItemStatusInProgress = Literal["in_progress",]


OutputFunctionCallItemStatusIncomplete = Literal["incomplete",]


OutputFunctionCallItemStatusCompleted = Literal["completed",]


OutputFunctionCallItemStatusUnionTypedDict = TypeAliasType(
    "OutputFunctionCallItemStatusUnionTypedDict",
    Union[
        OutputFunctionCallItemStatusCompleted,
        OutputFunctionCallItemStatusIncomplete,
        OutputFunctionCallItemStatusInProgress,
    ],
)


OutputFunctionCallItemStatusUnion = TypeAliasType(
    "OutputFunctionCallItemStatusUnion",
    Union[
        OutputFunctionCallItemStatusCompleted,
        OutputFunctionCallItemStatusIncomplete,
        OutputFunctionCallItemStatusInProgress,
    ],
)


class OutputFunctionCallItemTypedDict(TypedDict):
    type: OutputFunctionCallItemType
    name: str
    arguments: str
    call_id: str
    id: NotRequired[str]
    status: NotRequired[OutputFunctionCallItemStatusUnionTypedDict]


class OutputFunctionCallItem(BaseModel):
    type: OutputFunctionCallItemType

    name: str

    arguments: str

    call_id: str

    id: Optional[str] = None

    status: Optional[OutputFunctionCallItemStatusUnion] = None
