"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ShellServerToolType = Literal["shell",]


class ShellServerToolTypedDict(TypedDict):
    r"""Shell tool configuration"""

    type: ShellServerToolType


class ShellServerTool(BaseModel):
    r"""Shell tool configuration"""

    type: ShellServerToolType
