"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


DatetimeServerToolType = Literal["openrouter:datetime",]


class DatetimeServerToolParametersTypedDict(TypedDict):
    timezone: NotRequired[str]
    r"""IANA timezone name (e.g. \"America/New_York\"). Defaults to UTC."""


class DatetimeServerToolParameters(BaseModel):
    timezone: Optional[str] = None
    r"""IANA timezone name (e.g. \"America/New_York\"). Defaults to UTC."""


class DatetimeServerToolTypedDict(TypedDict):
    r"""OpenRouter built-in server tool: returns the current date and time"""

    type: DatetimeServerToolType
    parameters: NotRequired[DatetimeServerToolParametersTypedDict]


class DatetimeServerTool(BaseModel):
    r"""OpenRouter built-in server tool: returns the current date and time"""

    type: DatetimeServerToolType

    parameters: Optional[DatetimeServerToolParameters] = None
