"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatcontentitems import ChatContentItems, ChatContentItemsTypedDict
from openrouter.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


ChatUserMessageRole = Literal["user",]


ChatUserMessageContentTypedDict = TypeAliasType(
    "ChatUserMessageContentTypedDict", Union[str, List[ChatContentItemsTypedDict]]
)
r"""User message content"""


ChatUserMessageContent = TypeAliasType(
    "ChatUserMessageContent", Union[str, List[ChatContentItems]]
)
r"""User message content"""


class ChatUserMessageTypedDict(TypedDict):
    r"""User message"""

    role: ChatUserMessageRole
    content: ChatUserMessageContentTypedDict
    r"""User message content"""
    name: NotRequired[str]
    r"""Optional name for the user"""


class ChatUserMessage(BaseModel):
    r"""User message"""

    role: ChatUserMessageRole

    content: ChatUserMessageContent
    r"""User message content"""

    name: Optional[str] = None
    r"""Optional name for the user"""
