"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .compoundfilter import CompoundFilter, CompoundFilterTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Any, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


TypeFileSearch = Literal["file_search",]


FiltersType = Union[
    Literal[
        "eq",
        "ne",
        "gt",
        "gte",
        "lt",
        "lte",
    ],
    UnrecognizedStr,
]


Value1TypedDict = TypeAliasType("Value1TypedDict", Union[str, float])


Value1 = TypeAliasType("Value1", Union[str, float])


Value2TypedDict = TypeAliasType(
    "Value2TypedDict", Union[str, float, bool, List[Value1TypedDict]]
)


Value2 = TypeAliasType("Value2", Union[str, float, bool, List[Value1]])


class FileSearchServerToolFiltersTypedDict(TypedDict):
    key: str
    type: FiltersType
    value: Value2TypedDict


class FileSearchServerToolFilters(BaseModel):
    key: str

    type: Annotated[FiltersType, PlainValidator(validate_open_enum(False))]

    value: Value2


FiltersTypedDict = TypeAliasType(
    "FiltersTypedDict",
    Union[CompoundFilterTypedDict, FileSearchServerToolFiltersTypedDict, Any],
)


Filters = TypeAliasType(
    "Filters", Union[CompoundFilter, FileSearchServerToolFilters, Any]
)


Ranker = Union[
    Literal[
        "auto",
        "default-2024-11-15",
    ],
    UnrecognizedStr,
]


class RankingOptionsTypedDict(TypedDict):
    ranker: NotRequired[Ranker]
    score_threshold: NotRequired[float]


class RankingOptions(BaseModel):
    ranker: Annotated[Optional[Ranker], PlainValidator(validate_open_enum(False))] = (
        None
    )

    score_threshold: Optional[float] = None


class FileSearchServerToolTypedDict(TypedDict):
    r"""File search tool configuration"""

    type: TypeFileSearch
    vector_store_ids: List[str]
    filters: NotRequired[Nullable[FiltersTypedDict]]
    max_num_results: NotRequired[int]
    ranking_options: NotRequired[RankingOptionsTypedDict]


class FileSearchServerTool(BaseModel):
    r"""File search tool configuration"""

    type: TypeFileSearch

    vector_store_ids: List[str]

    filters: OptionalNullable[Filters] = UNSET

    max_num_results: Optional[int] = None

    ranking_options: Optional[RankingOptions] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["filters", "max_num_results", "ranking_options"]
        nullable_fields = ["filters"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
