"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemtext import (
    ChatMessageContentItemText,
    ChatMessageContentItemTextTypedDict,
)
from openrouter.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


SystemMessageRole = Literal["system",]


SystemMessageContentTypedDict = TypeAliasType(
    "SystemMessageContentTypedDict",
    Union[str, List[ChatMessageContentItemTextTypedDict]],
)
r"""System message content"""


SystemMessageContent = TypeAliasType(
    "SystemMessageContent", Union[str, List[ChatMessageContentItemText]]
)
r"""System message content"""


class SystemMessageTypedDict(TypedDict):
    r"""System message for setting behavior"""

    role: SystemMessageRole
    content: SystemMessageContentTypedDict
    r"""System message content"""
    name: NotRequired[str]
    r"""Optional name for the system message"""


class SystemMessage(BaseModel):
    r"""System message for setting behavior"""

    role: SystemMessageRole

    content: SystemMessageContent
    r"""System message content"""

    name: Optional[str] = None
    r"""Optional name for the system message"""
