"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatjsonschemaconfig import ChatJSONSchemaConfig, ChatJSONSchemaConfigTypedDict
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatFormatJSONSchemaConfigType = Literal["json_schema",]


class ChatFormatJSONSchemaConfigTypedDict(TypedDict):
    r"""JSON Schema response format for structured outputs"""

    type: ChatFormatJSONSchemaConfigType
    json_schema: ChatJSONSchemaConfigTypedDict
    r"""JSON Schema configuration object"""


class ChatFormatJSONSchemaConfig(BaseModel):
    r"""JSON Schema response format for structured outputs"""

    type: ChatFormatJSONSchemaConfigType

    json_schema: ChatJSONSchemaConfig
    r"""JSON Schema configuration object"""
