"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatchoice import ChatChoice, ChatChoiceTypedDict
from .chatusage import ChatUsage, ChatUsageTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


ChatResultObject = Literal["chat.completion",]


class ChatResultTypedDict(TypedDict):
    r"""Chat completion response"""

    id: str
    r"""Unique completion identifier"""
    choices: List[ChatChoiceTypedDict]
    r"""List of completion choices"""
    created: float
    r"""Unix timestamp of creation"""
    model: str
    r"""Model used for completion"""
    object: ChatResultObject
    system_fingerprint: Nullable[str]
    r"""System fingerprint"""
    service_tier: NotRequired[Nullable[str]]
    r"""The service tier used by the upstream provider for this request"""
    usage: NotRequired[ChatUsageTypedDict]
    r"""Token usage statistics"""


class ChatResult(BaseModel):
    r"""Chat completion response"""

    id: str
    r"""Unique completion identifier"""

    choices: List[ChatChoice]
    r"""List of completion choices"""

    created: float
    r"""Unix timestamp of creation"""

    model: str
    r"""Model used for completion"""

    object: ChatResultObject

    system_fingerprint: Nullable[str]
    r"""System fingerprint"""

    service_tier: OptionalNullable[str] = UNSET
    r"""The service tier used by the upstream provider for this request"""

    usage: Optional[ChatUsage] = None
    r"""Token usage statistics"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["service_tier", "usage"]
        nullable_fields = ["system_fingerprint", "service_tier"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
